/*****************************************************************************
 *
 * proxjs-full.js -- external script for sidki's Proxomitron config
 *
 * This is the full version, used in "light config mode" and above.
 *
 * Last edited: 2009-07-18
 *
 *****************************************************************************/

/* ====================================
   Namespace for various assignments.
   ==================================== */

prxO.oAss = {

  // Page Load Timer Part I. - hpguru
  asLdStart : (prxO.oSet.$toDo & 4) ? new Date().getTime() : null,

  // May get overwritten.
  asDate : Date,
  asUesc : unescape,

  // Does this browser support cssText and/or XPath?
  asTcss : document.documentElement && document.documentElement.style &&
    document.documentElement.style.cssText != undefined,
  asXpath : !!document.evaluate,

  // Is this a normal stand-alone window?
  asWinNormal : !window.opener || window.name.indexOf("prx_") == 0,

  // Regex for escaping ampersands (XHTML compliance).
  asReAmp : /&(?!#|amp;|apos;|gt;|lt;|quot;)/g

};

if (!prxO.oAss.asWinNormal) {
  try { prxO.oAss.asWinNormal = window.opener.location.href == window.location.href }
  catch (er) {}
}

/* ====================================
   Set some flags -- The "prxO" object has been created already.
   ==================================== */

// This flag indicates where we currently are in our script. Three stages:
// 1 -> Beginning.
// 2 -> End of page.
// 3 -> Onload event has completed.
prxO.oiLoaded = 1;

// Browser detection. - hpguru
if (window.opera)
  prxO.oiIsOp = window.opera.version ? window.opera.version() : 1;
else if (document.getElementById) {
  if (document.all) prxO.oiIsIE = document.documentMode || 1;
  else if (window.Window) prxO.oiIsMoz = true;
  else prxO.oiIsW3C = true;
}
else if (document.layers) prxO.oiIsNN = true;

// Force offscreen buffering to speed up rendering, default is auto. - hpguru
if (prxO.oiIsIE) window.offscreenBuffering = true;

/* ====================================
   Required References and Declarations.
   ==================================== */

// May get overwritten.
document.PrxRLcreateElement = document.createElement;

// Replaced browser info.
document.PRXreferrer = unescape(prxO.oNce.ncFrom);
navigator.PRXuserAgent = prxO.oNce.ncWith;

// Works its way up to the top window later.
prxO.oTop = window;

// Dummies.
var prxVoidV = "";
function PrxVoidF() { return ""; }

// Prophylactic definitions.
var expires = new Date(0);

// Called by Proxomitron instead of the real names.
if (prxO.oiIsMoz) {
  Window.prototype.PrxRLsetTimeout = Window.prototype.setTimeout;
  Window.prototype.PrxRLsetInterval = Window.prototype.setInterval;
} else {
  PrxRLsetTimeout = window.setTimeout;
  PrxRLsetInterval = window.setInterval;
}

/* ====================================
   Namespace for internal routines. - ...
   ==================================== */

prxO.oInt = {

  // Choose the right method for creating and getting tags, depending on
  // whether an XML namespace is present or not.
  inMakeEl : function (el) {
    return prxO.oSet.$_xns ? document.createElementNS(prxO.oSet.$_xns, el) :
      document.PrxRLcreateElement(el);
  },
  inGetEl : function (el) {
    if (!document.getElementsByTagName) return false;
    return prxO.oSet.$_xns ? document.getElementsByTagNameNS(prxO.oSet.$_xns, el) :
      document.getElementsByTagName(el);
  },

  // Choose the right method for setting the style attribute value.
  inSetCSS : function (node, css) {
    if (prxO.oAss.asTcss) node.style.cssText = css;
    else node.setAttribute("style", css);
  },

  // Checks if the given target refers to an existing frame or window.  Special
  // target names are ok.  Names starting with prx_ (e.g. bookmarklet windows)
  // are ok.  If the target matches an existing frame, ok.  Otherwise, no soup
  // for you. - Paul Rupe
  inTgCheck : function (t) {
    var n;
    return t.search(/^(?:_(?:top|parent|self|content|main)$|prx_)/) == 0 ||
      (!!(n = prxO.oTop.prxO.oAss.asNames) && n.indexOf("," + t + ",") != -1);
  },

  // Open link targets that refer to non-existing windows in the top window.
  // - Paul Rupe, sidki, z12
  inTgLinks : function () {
    if (!(prxO.oSet.$toDo & 32)) return;

    // Check if given node or its first child have an onclick attribute.
    function noClick(nd) {
      return !(nd.getAttribute("onclick") || (nd = nd.firstChild) && nd.onclick);
    }

    // Maximum links to check.
    var l = 1200, i, f, t, d, s;

    // Check for XPath support, fall back to links collection, fall back to
    // getElementsByTagName.
    if (prxO.oAss.asXpath) {
      t = []; d = document.evaluate(
        "//a[@target and not(starts-with(@href, 'javascript:')) and not(starts-with(@class, 'Pr0x'))]",
        document, null, 0, null);
      while ((f = d.iterateNext()) && (s = t.length) < l)
        if (!this.inTgCheck(f.target) && noClick(f)) t[s] = f;
      for (i = 0; f = t[i]; i++) f.target = "_top";
    } else {
      d = document.links || this.inGetEl("a");
      if (d.length > l) return;
      for (i = 0; f = d[i]; i++) {
        if ((t = f.target) &&
            (typeof f.protocol != "string" || f.protocol != "javascript:") &&
            f.className.indexOf("Pr0x") != 0 &&
            !this.inTgCheck(t) && noClick(f))
          f.target = "_top";
      }
    }

  },

  // Temporary handles for the W3C and IE event unregistration methods.
  inEventRemT : prxO.oiIsIE ? window.detachEvent : window.removeEventListener,

  // Cross-browser event listener registration and unregistration
  // - Mozilla/IE/Opera/NN4. - Scott Andrew LePera
  inEventAdd : function (obj, evn, fn, cap) {
    var rl = (obj == window || obj == document || obj == prxO.oBody) ? "PrxRL" : "";
    if (!prxO.oiIsIE && obj.addEventListener)
      obj[rl + "addEventListener"](evn, fn, cap || false);
    else if (obj.attachEvent)
      obj[rl + "attachEvent"]("on" + evn, fn);
    else obj["on" + evn] = fn;
  },
  inEventRem : function (obj, evn, fn, cap) {
    if (!prxO.oiIsIE && obj.removeEventListener) {
      if (this.inEventRemT) {
        window.removeEventListener = this.inEventRemT;
        delete this.inEventRemT;
      }
      obj.removeEventListener(evn, fn, cap || false);
    } else if (obj.detachEvent) {
      if (this.inEventRemT) {
        window.detachEvent = this.inEventRemT;
        delete this.inEventRemT;
      }
      obj.detachEvent("on" + evn, fn);
    }
  },

  // Set some of an object's event handlers to null Part I. - Paul Rupe
  inClearEvent : function (pxA) {
    if (!pxA) return;
    var pxE = [
      "onmouseleave",
      "onmouseout",
      "onmousewheel",
      "onblur",
      "onfocus",
      "onfocusout",
      "oncontextmenu",
      "oncopy",
      "ondeactivate",
      "onhelp",
      "onlosecapture",
      "onpropertychange",
      "onselect",
      "onselectstart",
      "onbeforeunload",
      "onunload"
    ];

    if (this.in_onclick) pxE[pxE.length] = "onclick";
    if (this.in_onkeydown) pxE[pxE.length] = "onkeydown";
    if (this.in_onmousedown) pxE[pxE.length] = "onmousedown";
    if (this.in_onmouseup) pxE[pxE.length] = "onmouseup";
    if (this.in_onbeforeprint) pxE[pxE.length] = "onbeforeprint";
    if (this.in_onafterprint) pxE[pxE.length] = "onafterprint";
    if (this.in_onscroll) pxE[pxE.length] = "onscroll";
    if (this.in_onresize) pxE[pxE.length] = "onresize";

    // Asking the Document object for defined event handlers is slow,
    // so nullify them unconditionally there.
    for (var i = 0, pxO; pxO = pxE[i]; i++)
      if (pxA == document || pxA[pxO]) pxA[pxO] = null;
  },

  // Create the button.
  inButCreate : function (pxO, pxN, pxF, pxB, pxM) {

    // Escape function code for display.
    pxF = pxF.replace(/&/g, "&amp;");
    pxF = pxF.replace(/</g, "&lt;");
    pxF = pxF.replace(/\r/g, "");
    pxF = pxF.replace(/\n/g, "%3Cbr class=%22Pr0xFly-Br%22 /%3E");
    pxF = pxF.replace(/"/g, "&quot;");

    var rTag = prxO.oInt.inMakeEl("input");
    rTag.className = "Pr0xBtn-Input";
    rTag.type = "button";
    rTag.name = pxN;
    rTag.value = pxN;
    rTag.onmouseover = function (event) {
      prxO.oFly.flShow("%3Cdiv id=%22pr0xFlyCt-Div%22%3E" +
      "%3Cspan class=%22Pr0xFly-Span%22%3Escope: " + pxO +
      (pxM ? " -- match: " + pxM.match(/([\w.=]+)[^\w.]*$/)[1] : "") +
      ":%3C/span%3E%3Cbr class=%22Pr0xFly-Br%22 /%3E" + pxF + "%3C/div%3E",event,0);
    };
    rTag.onmouseout = prxO.oFly.flDHide;
    rTag.onclick = pxB;

    prxO.oInt.inDOMready(rTag, 1);
  },

  // Various Event Listeners to Buttons Part III. - sidki
  inButListen : function (scope, evn, fn, cap) {
    if (!fn) return false;
    var that = this, pxA = (typeof cap == "boolean");
    if (!pxA) evn = evn.substr(2);

    function lTest(pxB, pxZ, pxE, pxI) {

      // See if the passed listener is block-worthy or not.
      if (pxZ != evn) return false;
      if (that.inCatch)
        for (var i = 0, l; l = that.inCatch[i]; i++)
          if (l == String([scope, evn, fn, cap])) return true;
      var pxM, pxF = String(fn), skip = (pxE && pxF.search(pxE) != -1);
      if (!skip && pxI) {
        if ((pxM = pxF.match(pxI))) pxM = pxM[0];
        skip = !pxM;
      }
      if (skip) return false;
      if (!pxB) return true;

      // It is block-worthy, so create a button.
      var pxO = String(scope); pxO += pxA ? " -- capture: " + cap : "";
      var pxT = pxA ? "listen: " : "attach: "; pxT += evn;
      that.inButCreate(pxO, pxT, pxF, fn, pxM);
      if (!that.inCatch) that.inCatch = [];
      that.inCatch[that.inCatch.length] = [scope, evn, fn, cap];
      return true;
    }

    // Test the current listener.
    var moEx = /\.altKey/,
    moIn = /open ?\(|Open ?\(|eval ?\(|\.(?:(?:src|href)(?: ?=|\.)|button ?[!=]= ?2)|dragleave/;
    return (
      lTest(1, "click", moEx, moIn) ||
      lTest(1, "mousedown", moEx, moIn) ||
      lTest(1, "mouseup", null, /\.(?:get(?:Attribute|RangeAt)|location)/) ||
      lTest(1, "load", null, /Math\.random|\.(?:createElement ?\( ?["'](?:script|SCRIPT)|preload)|expires ?=|float/) ||
      lTest(1, "contextmenu") ||
      lTest(1, "copy") ||
      lTest(1, "error") ||
      lTest(0, "beforeunload") ||
      lTest(0, "unload")
    );
  },

  // Create Popup Blocked Notification. - Michael Buerschgens, JD
  inPopURL : function (url, enam, why) {
    var s, f = "http://local.ptron/sidki_h_"; f += prxO.oSet.$_cfg; f += "/pop-";

    // Append image link.
    if (prxO.oSet.$popUp & 2) {
      var l = prxO.oInt.inMakeEl("a"),
      oSpan = "%3Cspan class=%22Pr0xFly-Span%22%3E",
      cSpan = "%3C/span%3E", br = "%3Cbr class=%22Pr0xFly-Br%22 /%3E",
      p = prxO.oInt.inMakeEl("img");
      p.src = f + (url ? "link.gif" : "blind.gif");
      p.className = "Pr0xPop-Img"; p.width = 17; p.height = 17; p.border = 0;
      p.onmouseover = function (event) {
        prxO.oFly.flShow("%3Cdiv id=%22pr0xFlyCt-Div%22%3E" +
        oSpan + "Popup blocked" + (url ? " -- click to launch:" : ":") +
        (enam ? br + "target: " + cSpan + enam + oSpan : "") +
        (why ? br + "event: " + cSpan + why + oSpan : "") +
        br + "url: " + cSpan + url + "%3C/div%3E",
        event,0);
      };
      p.onmouseout = prxO.oFly.flDHide;
      l.href = url; l.target = "_top"; l.appendChild(p);
      this.inDOMready(l);
    }

    // Append sound tag.
    if (prxO.oSet.$popUp & 4) {
      if (prxO.oiIsIE) s = prxO.oInt.inMakeEl("bgsound");
      else if (prxO.oiIsOp) {
        s = prxO.oInt.inMakeEl("iframe");
        s.width = 0; s.height = 0; s.frameBorder = 0;
      } else {
        s = prxO.oInt.inMakeEl("embed");
        s.setAttribute("autostart", true);
        var m, n, i;
        for (i in navigator.plugins)
          if ((m = navigator.plugins[i].name) && m.indexOf("Windows Media Player") == 0) {
            n = "application/x-mplayer2"; break;
          }
        s.width = 0; s.height = 0; s.type = n || "audio/x-wav";
      }
      s.src = f + "up.wav";
      this.inDOMready(s);
    }
  },

  // Print messages dynamically to the footer. - sidki
  inFooter : function (level, title, msg) {
    if (prxO.oSet.$_level < level) return;
    msg = (typeof msg == "string") ? msg.replace(/\n/g, "//") : msg;
    var tag = prxO.oInt.inMakeEl("span");
    tag.className = "Pr0x";
    tag.style.display = "inline";
    // Use createTextNode instead of innerHTML to get formatting right.
    tag.appendChild(document.createTextNode(" \u2022\u00A0" + title + ": " + msg));
    this.inDOMready(tag);
  },

  // Add bottom links and buttons.
  inDOMadd : function (aTag, aStick) {
    var pxS;
    if (aStick) {
      var bTag = (aStick == 1) ? "span" : "*",
      tagThis = prxO.oAss.asDivNode.getElementsByTagName(bTag);
      for (var i = 0, t; t = tagThis[i]; i++)
        if (t.className.indexOf(" Pr0x") == -1) {
          pxS = t;
          break;
        }
    }
    if (pxS) prxO.oAss.asDivNode.insertBefore(aTag, pxS);
    else prxO.oAss.asDivNode.appendChild(aTag);
  },

  // Add supplied elements to an array, until the entire page is accessible
  // via the DOM. - sidki
  inDOMready : function (aTag, aStick) {
    if (prxO.oAss.asDivNode.id) this.inDOMadd(aTag, aStick);
    else {
      if (!prxO.oNce) return;
      if (!prxO.oNce.ncColl) prxO.oNce.ncColl = [];
      prxO.oNce.ncColl[prxO.oNce.ncColl.length] = [aTag, aStick];
    }
  },

  // Declare the style selector. - Tantek Celik
  inStyleSwitch : function () {
    var sheets = ",", options = "<option selected>document default</option>";
    for (var i = 0, d = document.styleSheets; i < d.length; i++) {
      var s = d[i], tt = s.title;
      if (tt != "" && tt != undefined)
        if (sheets.indexOf("," + tt + ",") == -1) {
          sheets += tt; sheets += ",";
          options += "<option>"; options += tt; options += "</option>";
        }
    }
    var dw = this.inMyPop("", ",width=201,height=124").document;
    dw.write(
      "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"\n\"http://www.w3.org/TR/html4/strict.dtd\">" +
      "\n<html><head><title>Select Style Sheet</title>\n<meta http-equiv=\"Content-Type\" content=\"text/html; charset=iso-8859-1\">" +
      "\n<style type=\"text/css\">\nbody{margin:0;font:12px/20px Verdana,Arial,sans-serif;background:#CEDFEF;}" +
      "\ndiv{margin:0;padding:15px 10px 15px 10px}\nselect{width:170px;background:#A5CFF7;}\n</style>" +
      "\n<script type=\"text/javascript\">\nfunction choosess(tt){var x=window.opener.document;" +
      "for(var i=0,d=x.styleSheets;i<d.length;i++){var s=d[i];var ti=s.title;if(ti!=\"\" && ti!=undefined && ti!=tt)s.disabled=true;else s.disabled=false;}}\n</script>" +
      "\n</head>\n<body>\n<div>" +
      "\n<select id=\"st\" size=5 onkeypress=\"var k=event.keyCode;if(k==13 || k==3 || k==27){window.close()}\"" +
      " onchange=\"if(this.selectedIndex!=-1)choosess(this.options[this.selectedIndex].text);\">" + options + "</select>" +
      "\n</div>\n</body></html>"
    );
    dw.close(); dw.getElementById("st").focus();
  },

  // Proxomitron's own popups.  Needed for pages that block direct access to
  // the "open" method later on. - sidki
  inMyPop : function (w1, w2) {
    var x = (typeof PrxRLopen != "undefined") ? PrxRLopen : window.open;
    if (!w2) return x(w1, "_blank");
    var xatr  = "location=0,status=0,scrollbars=1,menubar=0,resizable=1,left=";
    xatr += screen.width * .01; xatr += ",top=";
    xatr += prxO.oiIsOp ? screen.height * .05 : screen.height * .12; xatr += w2;
    return x(w1, "prx_menu", xatr);
  },

  // Add or update the "Toggle xxx Flash Object(s)" bottom link.
  inUpFlash : function () {
    var ceci = arguments.callee;
    if (!ceci.fTag) {
      ceci.fTag = prxO.oInt.inMakeEl("span");
      ceci.fTag.className = "Pr0xToggleI Pr0x";
      ceci.fTag.style.display = "inline";
      ceci.fTag.innerHTML = "&#8593;<a class=\"Pr0xToggleI Pr0x\" href=\"javascript:prxO.oInt." +
        "inToggleB('Pr0xFlash','cl','span,object');\" title=\"Toggle " +
        "1 Flash Object\" target=\"_self\">flash</a> "
      prxO.oInt.inDOMready(ceci.fTag, 2);
    } else
      ceci.fTag.getElementsByTagName("a")[0].title = "Toggle " + prxO.oiFlash + " Flash Objects";
  },

  // Get the direct link to the intercepted Flash. - z12, sidki
  inGetFlash : function (node) {
    this.inUpFlash();
    var mom = node.parentNode;
    if (!mom) return;
    while (typeof mom.className == "string" && mom.className.indexOf("Pr0xFlash") != 0)
      mom = mom.parentNode;
    if (!mom.nextSibling) return;
    var mov, obj = mom.nextSibling, typ = obj.tagName.toLowerCase();
    while ((typ == "span" || typ == "font" || typ == "p") && obj.firstChild) {
      obj = obj.firstChild; typ = obj.tagName.toLowerCase();
    }
    while (typ == "br" && obj.nextSibling) {
      obj = obj.nextSibling; typ = obj.tagName.toLowerCase();
    }
    if (prxO.oiIsIE) mov = obj.rmov || obj.Movie || obj.SRC || obj.src;
    else {
      if (typ == "embed") mov = obj.getAttribute("src");
      else if (typ == "object" && !(mov = obj.data) && prxO.oAss.asXpath) {
        mov = document.evaluate(
         "embed | param[translate(@name, 'MOVIE', 'movie')='movie' or translate(@name, 'SRC', 'src')='src']",
          obj, null, 9, null).singleNodeValue;
        mov = mov ? mov.getAttribute("src") || mov.value : null;
      }
    }

    if (mov && node.nextSibling && node.nextSibling.nextSibling)
      node.nextSibling.nextSibling.href = mov;
  },

  // Get the 'n'th ancestor of given node. - Sadiq
  inGoUp : function (node, n) {
    for (var i = 0; i < n; i++) node = node.parentNode; return node;
  },

  // Toggle (show/hide) specified tags. - sidki
  inToggleA : function () {
    for (var i = 0, pxA, pxH; pxA = arguments[i]; i++) {
      if (pxA.style.display == "none" || pxA.style.visibility == "hidden") {
        if (prxO.oiIsIE || pxA.tagName.toLowerCase() == "span") {
          pxA.style.display = "inline"; pxA.style.visibility = "visible";
        } else {
          pxH = prxO.oAss.asTcss ? pxA.style.cssText : pxA.getAttribute("style");
          pxH = pxH.replace(/((display|visibility): *(none|hidden)[; ]*)+/i, "");
          pxH ? prxO.oInt.inSetCSS(pxA, pxH) : pxA.removeAttribute("style");
        }
      } else { pxA.style.display = "none"; pxA.style.visibility = "hidden"; }
    }
  },
  inToggleB : function (nam, atr, tags, num) {
    var m, i, a, t, tagThis, tagArray = tags.split(",");
    num = num || 0;
    for (m = 0; a = tagArray[m]; m++) {
      tagThis = this.inGetEl(a);
      for (i = 0; t = tagThis[i]; i++)
        if ((atr == "cl" && nam == t.className.split(" ")[num]) ||
          (atr == "id" && nam == t.id)) {
          if (nam == "Pr0xFlash") this.inToggleD(t);
          else this.inToggleA(t);
        }
    }
  },
  inToggleC : function (nam, tag) {
    if (!tag) {
      while (nam.className.indexOf("Pr0xToggle") < 0) nam = nam.parentNode;
      nam = nam.nextSibling; nam.src = nam.longDesc; nam.style.display = "inline";
    } else {
      var i, t, tagThis = this.inGetEl(tag);
      for (i = 0; t = tagThis[i]; i++) {
        if (t.className.indexOf(nam) == 0) {
          if (t.style.display == "none") {
            t.src = t.longDesc; t.style.display = "inline";
          } else {
            t.src = "about:blank"; t.style.display = "none";
          }
        }
      }
    }
  },
  inToggleD : function (pxA, pxT) {
    function doTog(pA, pT) {
      if (pA.className == "Pr0xFlash") {
        if (prxO.oiIsIE) {
          var pB = (pA.Movie || pA.SRC) ? pA : pA.firstChild;
          if (pB.rmov) {
            var pC = pB.Movie ? "Movie" : "SRC";
            if (pB[pC] == "about:blank") pB[pC] = pB.rmov;
          }
        }
      }
      else if (pT) {
        while (typeof pxA.className == "string" && pxA.className.indexOf("Pr0xToggle") < 0)
          pxA = pxA.parentNode;
        pA = pxA;
      }
      if (pA.style) pA.style.display = (pA.style.display == "none") ? "inline" : "none";
    }
    doTog(pxA, true);
    var pD, pF;
    if (pxT && (pD = pxA.nextSibling)) {
      var pE = pD.getElementsByTagName("span")[0];
      if (pE && pE.className.indexOf("Pr0xToggle") > -1) {
        doTog(pE);
        if ((pF = pE.nextSibling)) doTog(pF);
      }
      doTog(pD);
    }
  },

  // Stop event bubbling.
  inStopEv : function (e) {
    e = e || window.event;
    if (e.stopPropagation) e.stopPropagation();
    else e.cancelBubble = true;
  },

  // Set our own status if needed.
  inStatus : function () {
    window.defaultStatus = prxO.oAss.asStatus;
    if (!window.status || status.prox) window.status = window.defaultStatus;
  },

  // Weapon of mass destruction...
  inDone : function (x) {
    if (prxO.oSet.$_level >= 5) return;
    if (x) x = document.getElementById ? document.getElementById(x) : null;
    else {
      x = this.inGetEl("script");
      if (x) x = x[x.length - 1];
    }
    if (x) x.parentNode.removeChild(x);
  }

};

/* ====================================
   Namespace for initial temporary functions.
   ==================================== */

prxO.oNce = {
  ncDocFrag : document.createDocumentFragment(),

  // Get Window Names Part I.  If this window has a name, append it to the
  // "Frame Names" variable. - z12
  ncTgAdd : function (s) {
    var t = s.name;
    if (!t) return;
    var n = prxO.oTop.prxO.oAss.asNames, m = "," + t + ",";
    if (!n) prxO.oTop.prxO.oAss.asNames = m;
    else if (n.indexOf(m) == -1) prxO.oTop.prxO.oAss.asNames += t + ",";
  },

  // Insert our CSS.
  ncCSSAdd : function () {
    var pxA = ((prxO.oSet.$css & 8) ? "" : "http:/");
    pxA += "/local.ptron/sidki_h_"; pxA += prxO.oSet.$_cfg;
    pxA += "/CSS/dummy.css?join="; pxA += prxO.oSet.$_cssSpec.join();
    if (!document.PrxRLcreateElement) {
      document.write("\n<link rel=\"stylesheet\" type=\"text/css\" href=\"" +
        pxA + "\"" + prxO.oSet.$_xml + ">");
      return;
    }
    var pxG = this.ncStyle;
    this.ncStyle = prxO.oInt.inMakeEl("style");
    this.ncStyle.lang = "x-prox-css";
    this.ncStyle.media = "all";
    this.ncStyle.type = "text/css";
    if (!prxO.oiIsIE) this.ncStyle.textContent = "@import url(" + pxA + ");";
    var pxS = document.getElementById("pr0xScrLink");
    if (pxG && pxG.parentNode) pxG.parentNode.replaceChild(this.ncStyle, pxG);
    else if (!pxS) {
      if ((pxS = document.styleSheets) && (pxS = pxS[0]) &&
           (pxS = pxS.owningElement || pxS.ownerNode))
        pxS.parentNode.insertBefore(this.ncStyle, pxS);
      else if ((pxS = prxO.oInt.inGetEl("head")[0]))
        pxS.appendChild(this.ncStyle);
      else return;
    }
    else if (pxS.nextSibling) pxS.parentNode.insertBefore(this.ncStyle, pxS.nextSibling);
    else pxS.parentNode.appendChild(this.ncStyle);
    if (prxO.oiIsIE) this.ncStyle.styleSheet.addImport(pxA);
  },

  // Various Events to Buttons Part I. - Paul Rupe, sidki
  // Create a button to call a given event handler directly if such a handler
  // is defined.  Rather than disable e.g. window.onload completely, this lets
  // you call it at will in case some page requires it to function.
  ncButEvent : function (pxO, pxN, pxE, pxI) {

    // See if the passed handler function is block-worthy or not.
    if (prxO.oInt["in_" + pxN] !== undefined) return;
    var pxT = (pxO === "document") ? document : (pxO === prxO.oBody) ?
      pxO : window, pxP = pxT[pxN];
    if (!pxP) return;
    var pxF;
    if (typeof pxP == "function") try { pxF = String(pxP); } catch (er) { pxF = null; }
    if (!pxF) {
      pxF = (pxF === null) ? "stringify " : "convert ";
      prxO.oInt.inFooter(4, "Prox intercept", "Can't " + pxF + pxO + "." + pxN + "!");
      prxO.oInt["in_" + pxN] = true;
      return;
    }
    var pxM, pxR, pxQ, skip;

    // Test the handler function.
    skip = (pxE && pxF.search(pxE) != -1);
    if (!skip && pxI) {
      if ((pxM = pxF.match(pxI))) pxM = pxM[0];
      skip = !pxM;
    }

    // Expand the called function, if any.
    if (skip) {
      pxR = /^\n?function(?: \w+)? ?\(\w*\)[\s\n]?{[\s\n]*(?:(?:javascript:|return)[\s\n]*)?([\w$]+) ?\([^)]*\)\W+$/;
      if ((pxR = pxF.match(pxR)) && (pxR = window[pxR[1]])) {
        pxR = String(pxR);

        // Test the called function.
        skip = (pxE && pxR.search(pxE) != -1);
        if (!skip && pxI) {
          if ((pxM = pxR.match(pxI))) {
            pxM = pxM[0];
            pxF += "\n%3Cspan class=%22Pr0xFly-Span%22%3Eexpanded function:%3C/span%3E\n" + pxR;
          }
          skip = !pxM;
        }

      }
    }

    prxO.oInt["in_" + pxN] = !skip;
    if (skip) return;

    // It is block-worthy, so create a button.
    prxO.oInt.inButCreate(pxO, pxN, pxF, pxP, pxM);
  },

  // Executed once document.body is known to the DOM.
  ncBody : function () {

    // Set a reference to the body element.  Don't use "document.body" here,
    // "body" is a valid name for tag IDs.
    prxO.oBody = prxO.oInt.inGetEl("body")[0];

    // Permanent handles for W3C & IE event registration methods Part II.
    var i, pxZ, pxA = [];
    if (window.addEventListener) pxA[pxA.length] = "addEventListener";
    if (window.attachEvent) pxA[pxA.length] = "attachEvent";
    for (i = 0; pxA[i]; i++) {
      pxZ = pxA[i];
      prxO.oBody["PrxRL" + pxZ] = prxO.oBody[pxZ];

      // Various Event Listeners to Buttons Part II (start of body). - sidki
      if (prxO.oSet.$toButton & 2) prxO.oBody[pxZ] = window[pxZ];
    }
  },

  // Executed at end of page.
  ncBottom : function (wdisp, wcook, wcode) {

    // Register our onload event Part II (removal). - sidki
    // The previous registration was needed for framesets, which won't see this
    // part of code.  And for IE, which is excluded.
    if (!prxO.oiIsIE) prxO.oInt.inEventRem(window, "load", this.ncLoad);

    // Prevent Window Resizing Part II.  If this is a requested popup, resize
    // it to the dimensions that may have been blocked previously.
    if (!prxO.oAss.asWinNormal && prxO.oSet.$toDo & 64 && window.innerWidth) {
      if (window.PRXinnerWidth) window.innerWidth = window.PRXinnerWidth;
      else if (window.PRXouterWidth) window.outerWidth = window.PRXouterWidth;
      if (window.PRXinnerHeight) window.innerHeight = window.PRXinnerHeight;
      else if (window.PRXouterHeight) window.outerHeight = window.PRXouterHeight;
    }

    // Specific "onload" Events to Button - Paul Rupe, sidki
    if (prxO.oSet.$toButton & 4 && window.onload && !prxO.oAss.asWinTiny && prxO.oAss.asWinNormal) {
      var ldEx = /menu|<frameset|\.OnMedia/i,
      ldIn = /^\n*function SymOnLoad|^[^;]*(?:popu(?:p|nder)|track)\w*|location\.href ?=(?!=)|Math\.random|float(?! *:)|expires ?=|print ?\(|\.(?:click ?\( *\)|location ?=(?!=)|links\.length)/i;
      this.ncButEvent("window", "onload", ldEx, ldIn);
      if (prxO.oInt.in_onload)
        window.onload = document.body.onload = null;
    }

    // "onerror" Events to Button - sidki
    if (prxO.oSet.$toButton & 1) {
      this.ncButEvent("window", "onerror", /^\n*function \(pxMsg/);
      if (prxO.oInt.in_onerror)
        window.onerror = prxO.oSet._catchErrors ? prxO.oNce.ncOnerror : null;
    }
    // In case buttons are turned off but error catching is turned on...
    else if (prxO.oSet._catchErrors && !prxO.oiIsOp) window.onerror = prxO.oNce.ncOnerror;

    // Get Window Names Part III.  Names of "about:blank" iframes have to be
    // collected at this point.
    for (var i = 0, fr; fr = frames[i]; i++) try { this.ncTgAdd(fr); } catch (er) {}

    this.ncWrite = function () {

      // Reinsert our CSS, if removed by a page script.
      if (prxO.oSet.$_cssSpec.length) {
        var bIdx = this.ncStyle.innerHTML.indexOf("/local.ptron");
        if (!this.ncStyle.parentNode || bIdx < 11 || bIdx > 23) {
          this.ncCSSAdd();
          prxO.oInt.inFooter(4, "Prox CSS", "reinserted!");
        }
      }

      // If the current page doesn't have a body tag, or if we are in Light
      // Mode...
      if (!prxO.oBody) this.ncBody();

      // Set the main target element.  Values depend on rendering mode and
      // browser.
      prxO.oAss.asMode = document.compatMode;
      if ((prxO.oiIsOp < 9.5 || (prxO.oAss.asMode != "CSS1Compat" && !prxO.oSet.$_xns)) && prxO.oBody)
        prxO.oDoc = prxO.oBody;
      else prxO.oDoc = document.documentElement;

      // Check if this window is large enough to display Prox menu and bottom
      // links. - sidki
      var xc = prxO.oDoc.clientWidth, yc = prxO.oDoc.clientHeight,
      xs = prxO.oDoc.scrollWidth, ys = prxO.oDoc.scrollHeight;
      if ((prxO.oAss.asWinShort = ys <= yc) && prxO.oiIsMoz && xs > xc) prxO.oAss.asWinShort = 2;
      if (window.parent != window && prxO.oSet.$_level <= 4) {
        // Fx2 returns incorrect client width/height under heavy CPU load.
        var x = window.innerWidth || xc, y = window.innerHeight || yc;
        x = (xs > x) ? xs : x;
        y = (ys > y) ? ys : y;
        prxO.oAss.asWinTiny = x < 370 || y < 370;
      }

      // Adjust flyovers and Prox menu for non-statically positoned body elements
      // and for styled html elements in Mozilla.
      prxO.oAss.asWidth = 0;
      var bStyle = document.defaultView ?
        document.defaultView.getComputedStyle(prxO.oBody, null) :
        prxO.oBody.currentStyle;
      if (bStyle && bStyle.position != "static")
        prxO.oAss.asWidth = prxO.oiIsIE ? prxO.oBody.offsetLeft : (
          prxO.oiIsOp ? prxO.oDoc.clientWidth - bStyle.pixelWidth :
          Math.round(prxO.oDoc.clientWidth - parseFloat(bStyle.width) -
          parseFloat(bStyle.paddingLeft) - parseFloat(bStyle.paddingRight))
          ) / 2;
      // if (prxO.oAss.asWidth)
      //   prxO.oInt.inFooter(4, bStyle.position + " body x-adjust", prxO.oAss.asWidth + "px");

      if (wdisp) {
        var w = [];

        // Prepare the bottom links, if any.
        if (!prxO.oAss.asWinTiny) {
          var kills, rdisp = (wdisp == "none") ? wdisp : "inline";

          // Any incoming ad scripts?
          if ((kills = prxO.oNce.ncJsKills)) {
            var q, kill, justin = "";
            for (q = 0; kill = kills[q]; q++) {
              justin += "%3Cspan class=%22Pr0xFly-Span%22%3E";
              justin += kill[0]; justin += ":%3C/span%3E "; justin += kill[1];
              justin += "%3Cbr class=%22Pr0xFly-Br%22 /%3E";
            }
            w[w.length] = "<span class=\"Pr0xAlert Pr0x\" style=\"display:";
            w[w.length] = rdisp; w[w.length] = "\">&#8226;&#160;<a class=\"Pr0xAlert Pr0x\"";
            w[w.length] = " onmouseover=\"prxO.oFly.flShow('%3Cdiv id=%22pr0xFlyCt-Div%22%3E";
            w[w.length] = justin; w[w.length] = "%3C/div%3E',event,0);\"";
            w[w.length] = " onmouseout=\"prxO.oFly.flDHide();\">js in</a> </span>";
          }

          // See if Proxomitron has already captured any info.
          w[w.length] = wcode || "";

          // See if we want to display cookies, and if Proxomitron has captured
          // any already.
          if (wcook) {
            wcook = (wcook == 1) ? "" : wcook;
            var cd = "", dc = document.cookie;
            if (dc) {

              // Zap cookies on button click. - Jesse Ruderman
              prxO.oInt.inCookieZ = function () {
                var dom, sl, su, pa, pa2, i, coI, coA = document.cookie.split("; "),
                ex = new prxO.oAss.asDate(new prxO.oAss.asDate().getTime() - 1e11).toGMTString();
                for (dom = "." + location.host; dom; dom = ("" + dom).substr(1).match(/\..*$/))
                  for (sl = 0; sl < 2; ++sl)
                    for (pa = "/" + location.pathname; pa; pa = pa.substring(0, pa.lastIndexOf("/"))) {
                      pa2 = pa.slice(1) + "/";
                      for (su = 0; su < 2; ++su)
                        for (i = 0; coI = coA[i]; i++)
                          document.cookie = coI + "; domain=" + dom.slice(sl) +
                            "; path=" + pa2.substr(0, pa2.length - su) + "; expires=" + ex;
                    }
              }

              dc = dc.replace(/;\s?/g, ";%3Cbr class=%22Pr0xFly-Br%22 /%3E&#160;");
              dc = dc.replace(/</g, "&amp;lt;");
              dc = dc.replace(/\\/g, "&amp;#92;");
              dc = dc.replace(/"/g, "&amp;quot;");
              dc = dc.replace(/'/g, "&amp;#39;");
              dc = dc.replace(/%26(?!#|amp;|apos;|gt;|lt;|quot;)/g, "%26amp;");
              dc = dc.replace(prxO.oAss.asReAmp, "&amp;amp;");
              wcook += "%3Cdiv class=%22Pr0xFlyCk-Div%22%3ECookies in Session:%3C/div%3E&#160;";
              wcook += dc; wcook += "%3C/div%3E%3Cbutton class=%22Pr0xBtn-Button%22 ";
              wcook += "onclick=%22prxO.oInt.inCookieZ();%22%3ERemove Cookies%3C/button%3E";
            } else if (wcook) {
              wcook += "%3C/div%3E";
              cd = " style=\"text-decoration:line-through!important\"";
            }

            if (wcook) {
              w[w.length] = "<span class=\"Pr0xCookie Pr0x\""; w[w.length] = cd;
              w[w.length] = ">&#8226;&#160;<a class=\"Pr0xCookie Pr0x\" onmouseover=";
              w[w.length] = "\"prxO.oFly.flShow('%3Cdiv id=%22pr0xFlyCt-Div%22%3E";
              w[w.length] = wcook; w[w.length] = "',event,0);\"";
              w[w.length] = " onmouseout=\"prxO.oFly.flDHide();\">cookies</a>\n\t</span>";
            }
          }

          // See if the style selector should be invoked. - sidki
          var d;
          if (prxO.oSet.$toDo & 2 && (d = document.styleSheets)) {
            for (var i = 0; i < d.length; i++) {
              var s = d[i], tt = s.title, st;
              if (tt != "" && tt != undefined) st = 1;
            }
            if (st) {
              w[w.length] = "<span class=\"Pr0xBottom Pr0x\">";
              w[w.length] = "&#8593;<a class=\"Pr0xBottom Pr0x\"";
              w[w.length] = " href=\"javascript:prxO.oInt.inStyleSwitch();\">styles</a></span>\n";
            }
          }

          // Intercept calls to "location.replace" Part II. - Paul Rupe, sidki
          if (prxO.inCatchLocURL) {
            w[w.length] = "<span class=\"Pr0xRedir Pr0x\">";
            w[w.length] = "&#8593;<a class=\"Pr0xRedir Pr0x\" href=\""; w[w.length] = prxO.inCatchLocURL;
            w[w.length] = " \" target=_top>tame redirect</a></span>\n";
          }

          // Various Events to Buttons Part II (page has loaded). - Paul Rupe
          if (prxO.oSet.$toButton & 1) {
            this.ncButEvent("window", "onbeforeprint");
            this.ncButEvent("window", "onafterprint");
            this.ncButEvent("window", "onblur");
            this.ncButEvent("window", "onfocus");
            this.ncButEvent("window", "onscroll");
            this.ncButEvent("window", "oncopy");
            this.ncButEvent("window", "onresize", /\.(?:length\W|setTimeout|style\.)/);
          }
          if (prxO.oSet.$toButton & 8) {
            var keEx = /\.keyCode ?[;=?]/,
            clEx = /\.(?:style\.|altKey|shiftKey|close ?\()/,
            moEx = /\.(?:style\.|altKey|shiftKey)/,
            moIn = /return(\s+| ?\( ?)false|location(?:\.href)? ?=[^=]|open ?\(|\.(?:(?:src|href)(?: ?=|\.)|button ?== ?2|(?:random|getTime))/;

            this.ncButEvent(prxO.oBody, "onkeydown", keEx);
            this.ncButEvent("window", "onkeydown", keEx);
            this.ncButEvent("document", "onkeydown", keEx);

            this.ncButEvent(prxO.oBody, "onclick", null, moIn);
            this.ncButEvent("window", "onclick", clEx, moIn);
            this.ncButEvent("document", "onclick", clEx, moIn);

            this.ncButEvent(prxO.oBody, "onmousedown", null, moIn);
            this.ncButEvent("window", "onmousedown", moEx, moIn);
            this.ncButEvent("document", "onmousedown", moEx, moIn);

            this.ncButEvent(prxO.oBody, "onmouseup", null, moIn);
            this.ncButEvent("window", "onmouseup", moEx, moIn);
            this.ncButEvent("document", "onmouseup", moEx, moIn);

            this.ncButEvent(prxO.oBody, "oncontextmenu", null, moIn);
            this.ncButEvent("window", "oncontextmenu", moEx, moIn);
            this.ncButEvent("document", "oncontextmenu", moEx, moIn);
          }
        }

        // Add some attributes to our bottom DIV container.
        if (prxO.oAss.asWinShort)
          prxO.oInt.inSetCSS(prxO.oAss.asDivNode,
            "position: absolute; left: 0; bottom: " +
            ((prxO.oAss.asWinShort == 2) ? 15 : 2) + "px; display: " + wdisp + ";");
        else prxO.oAss.asDivNode.style.display = wdisp;
        prxO.oAss.asDivNode.id = "pr0xDom-Div";
        this.ncDocFrag.appendChild(prxO.oAss.asDivNode);
        if ((w = w.join(""))) prxO.oAss.asDivNode.innerHTML = w;

        // Append dynamic blocks if there are any already.
        if (this.ncColl) {
          var that = this;
          function addDyn() {
            for (var i = 0, c; c = that.ncColl[i]; i++)
              prxO.oInt.inDOMadd(c[0], c[1]);
          }
          if (prxO.oiIsOp || prxO.oiIsIE) PrxRLsetTimeout(addDyn, 0);
          else addDyn();
        }

      }

      // Clickable flyover Part II. - Dynamic Drive, sidki, Martin Konicek
      prxO.oFly.flObject = prxO.oInt.inMakeEl("div");
      prxO.oFly.flObject.id = "pr0xFly-Div";
      prxO.oFly.flObject.onmouseover = prxO.oFly.flClearHide;
      prxO.oFly.flObject.onmouseout = prxO.oFly.flDynHide;
      this.ncDocFrag.appendChild(prxO.oFly.flObject);
    }

    // Register our onload event Part III (re-add -> move to end-of-chain).
    // Executed outside framesets and for standards-compliant browsers only.
    if (!prxO.oiIsIE) prxO.oInt.inEventAdd(window, "load", this.ncLoad);

    // We've reached the end of the page.
    prxO.oiLoaded = 2;
    return true;
  },

  // Run this function at the very last. - ...
  ncFinal : function (pxSplit) {
    var i, z, t, fo, fr, d;

    // Add some info to the title, snip excessively large strings. - sidki
    if (prxO.oSet._titProxy || prxO.oSet._titMod || prxO.oSet._titTime) {
      var pxDp = prxO.oSet._titProxy ? "[Proxy] " : "", pxDt = document.title;
      if (prxO.oSet._titTime) {
        if (pxDt.length > 62) pxDt = pxDt.substr(0, 62) + "...";
        pxDt += " ~" + prxO.oSet._titTime;
      }
      pxDt += prxO.oSet._titMod ? " [" + prxO.oSet._titMod + "]" : "";
      document.title = pxDp + pxDt;
    }

    // Get Window Names Part IV.  IE denies access to the "prxO.oTop",
    // if "document.domain" has been changed after the variable was set.
    // So check again.
    try { z = typeof prxO.oTop.prxO.oAss.asNames; }
    catch (er) { prxO.oTop = window; }

    // Get the name of this window and all child frames, if any.
    this.ncTgAdd(window);
    for (i = 0; fr = frames[i]; i++) try { this.ncTgAdd(fr); } catch (er) {}

    // Once the top window has loaded, check the link targets in this window
    // and all child frames.
    if (prxO.oSet.$toDo & 32 && prxO.oTop == window) {
      for (i = 0; fr = frames[i]; i++)
        try { fr.prxO.oInt.inTgLinks(); } catch (er) {}
      prxO.oInt.inTgLinks();
    }

    // Set some of an object's event handlers to null Part II. - Paul Rupe
    if (prxO.oSet.$stopMe & 2) {
      prxO.oInt.inClearEvent(document);
      prxO.oInt.inClearEvent(prxO.oBody);
      prxO.oInt.inClearEvent(window);
    }

    // Various Event Listeners to Buttons Part IV (end of page). - sidki
    // Stop intercepting event listener registration now.
    if (prxO.oSet.$toButton & 2) {
      PrxRLsetTimeout(function () {
        if (window.PrxRLaddEventListener) {
          // There is no body in framesets.
          if (prxO.oBody) prxO.oBody.addEventListener = prxO.oBody.PrxRLaddEventListener;
          window.addEventListener = window.PrxRLaddEventListener;
          document.addEventListener = document.PrxRLaddEventListener;
        }
        if (window.PrxRLattachEvent) {
          // There is no body in framesets.
          if (prxO.oBody) prxO.oBody.attachEvent = prxO.oBody.PrxRLattachEvent;
          window.attachEvent = window.PrxRLattachEvent;
          document.attachEvent = document.PrxRLattachEvent;
        }
      }, 100);
    }

    // Proxomitron Menu Part II. - sidki
    if (prxO.oSet.$toDo & 1 && prxO.oSet.$_frameset != 2) {
      if (!prxO.oAss.asWinTiny) {
        prxO.oMen.meWriteI();
        prxO.oInt.inEventAdd(prxO.oiIsMoz ? window : document, "click", prxO.oMen.meInit, true);
        if (prxO.oiIsIE) // IE can't intercept during capture phase.
          prxO.oInt.inEventAdd(prxO.oBody, "click", prxO.oMen.meInit);
      } else {
        delete prxO.oInt.inClearEvent;
        delete prxO.oMen.meSet;
        delete prxO.oMen.meWriteI;
        delete prxO.oMen.meInit;
      }
    }
    else if (prxO.oSet.$_level < 5) delete prxO.oInt.inClearEvent;

    // Append our additions to the page.
    if (prxO.oSet.$_frameset != 2) prxO.oBody.appendChild(this.ncDocFrag);

    // Track last click if interception of popups, timers, or message boxes is
    // turned on. - Scott R. Lemmon
    if (prxO.oSet.$popUp & 1 || prxO.oSet.$stopMe & (4 | 8) || prxO.oSet._catchBoxes)
      prxO.oInt.inEventAdd(document, "mouseup", function () {
        prxO.oAss.asLastClick = prxO.oTop.prxO.oAss.asLastClick =
          new prxO.oAss.asDate().getTime();
      }, true);

    // Prepare for our status additions.
    prxO.oAss.asStatus = "";

    // Page Load Timer Part III. - hpguru
    if (prxO.oSet.$toDo & 4)
      prxO.oAss.asStatus += "Load Time (sec): " +
        pxSplit + (new prxO.oAss.asDate().getTime() - prxO.oAss.asLdStart) / 1000;

    // Time to status bar. - OZO
    if (prxO.oSet._sbTime) prxO.oAss.asStatus += " ~" + prxO.oSet._sbTime;

    // Last-Modified or ETag to status bar.
    if (prxO.oSet._sbMod) prxO.oAss.asStatus += " [" + prxO.oSet._sbMod + "]";

    if (prxO.oAss.asStatus) {
      if (prxO.oiIsOp) PrxRLsetTimeout(prxO.oInt.inStatus, 0);
      else prxO.oInt.inStatus();
      prxO.oInt.inEventAdd(window, "focus", prxO.oInt.inStatus, true);
    }

  },

  // The function that gets registered with the onload event.  Keep it simple
  // to avoid memory leaks in Mozilla.
  ncLoad : function () {

    // If our environment is gone, return (XMLHttpRequest/Ajax).
    if (!window.prxO) return;

    // Page Load Timer Part II. - hpguru
    var tsplit = (prxO.oSet.$toDo & 4 && prxO.oSet.$_level > 3) ?
      (new prxO.oAss.asDate().getTime() - prxO.oAss.asLdStart) / 1000 + " -> " : "";

    // If this gets executed and the "ncBottom" function didn't run before,
    // then we are apparently in a frameset.
    // Else, add our stuff to the end of page.
    (prxO.oiLoaded == 1) ? prxO.oSet.$_frameset = 2 : prxO.oNce.ncWrite();

    // Final jobs.
    prxO.oNce.ncFinal(tsplit);

    // Delete temporary routines that aren't needed anymore.
    if (prxO.oSet.$_level < 5) delete prxO.oNce;

    // All done.
    prxO.oiLoaded = 3;
  }

};

/* ====================================
   Clickable flyover Part I. - Dynamic Drive, sidki, Martin Konicek
   ==================================== */

// Pop-it menu - By Dynamic Drive.  For full source code and more DHTML
// scripts, visit http://www.dynamicdrive.com .  This credit MUST stay intact
// for use.
prxO.oFly = {
  flShow : function (which, e, movex) {
    if (!this.flObject) return;
    this.flClearHide();
    this.flHide();
    e = e || window.event;
    var offY = 10;
    this.flObject.innerHTML = (movex == 1) ? which : prxO.oAss.asUesc(which);

    // Find out the mouse position relative to the viewport. - sidki
    var hereX = (e.pageX || prxO.oDoc.scrollLeft + e.clientX) - prxO.oAss.asWidth;
    var hereY = e.pageY || prxO.oDoc.scrollTop + e.clientY;

    // If the mouse is too close to the viewports right or top edge, move
    // the position of the flyover to the left or bottom.
    var pWidth = this.flObject.offsetWidth;
    var pHeight = this.flObject.offsetHeight + offY;
    hereX = (movex && prxO.oDoc.clientWidth - e.clientX < pWidth) ?
      hereX - pWidth : hereX;
    hereY = (e.clientY < pHeight) ? hereY + offY : hereY - pHeight;
    var maxX = prxO.oDoc.clientWidth - hereX - 15;

    prxO.oInt.inSetCSS(this.flObject,
      "left: " + hereX + "px; top: " + hereY + "px; max-width: " + maxX + "px;");
    this.flIdShow = PrxRLsetTimeout(function () {
      prxO.oFly.flObject.style.visibility = "visible";
    }, 450);
  },

  flDHide : function () {
    prxO.oFly.flClearHide();
    prxO.oFly.flIdShow = PrxRLsetTimeout(prxO.oFly.flHide, 450);
  },

  flHide : function () {
    if (prxO.oFly.flObject) prxO.oFly.flObject.style.visibility = "hidden";
  },

  flClearHide : function () {
    if (prxO.oFly.flIdShow) clearTimeout(prxO.oFly.flIdShow);
  },

  // Make sure that moused-out-from node doesn't contain moused-out-to node.
  // - Peter-Paul Koch
  flDynHide : function (e) {
    e = e || window.event;
    var cdp, rt = e.relatedTarget || e.toElement,
    off = rt ? this.contains ? !this.contains(rt) : this.compareDocumentPosition ?
      !((cdp = this.compareDocumentPosition(rt)) & 16) && cdp : true : true;
    if (off) prxO.oFly.flHide();
  },

  // Make an anchor with the passed information. - Martin Konicek
  flLink : function (name, url) {
    return "<a class=\"Pr0xFly-A\" href=\"" +
      prxO.oAss.asUesc(url).replace(prxO.oAss.asReAmp, "&amp;") +
      "\">" + name + "</a>";
  }

};

/* ====================================
   Timers to button -- Intercept "setInterval" and "setTimeout" functions that
   are triggered before the page has completely loaded with a start/stop
   button. - sidki
   ==================================== */

if (prxO.oSet.$stopMe & (4 | 8)) {
  prxO.oTim = {
    tiAppend : function (meth, func, time) {

      // If this is the first call, initialize the variables.
      if (!this.tiColl) {
        this.tiColl = [];
        var rtext = !prxO.oiIsOp ?
          ",%3Cbr class=%22Pr0xFly-Br%22 /%3Eright-click to run once without delay" : "";

        // Escape function code for display.
        var s = String(func);
        s = s.replace(/&/g, "&amp;");
        s = s.replace(/</g, "&lt;");
        s = s.replace(/\r/g, "");
        s = s.replace(/\n/g, "%3Cbr class=%22Pr0xFly-Br%22 /%3E");
        s = s.replace(/"/g, "&quot;");

        this.tiFirst = {

          // On right-click run the first timer function just once and without
          // delay.  Opera ignores that.
          rclick : function () { PrxRLsetTimeout(func, 0); return false; },

          over : "%3Cspan class=%22Pr0xFly-Span%22%3Efirst instance" + ": " + meth + " " +
            time / 1000 + " second(s)" + rtext + ":%3C/span%3E%3Cbr class=%22Pr0xFly-Br%22 /%3E" + s
        };

        // Create the timer button.  "onmouseover" and "oncontextmenu" just
        // deal with the first timer instance.  "onclick" launches all
        // instances.
        this.tiTag = prxO.oInt.inMakeEl("input");
        this.tiTag.className = "Pr0xBtn-Input";
        this.tiTag.type = "button";
        this.tiTag.name = "timer";
        this.tiTag.value = "timer";
        this.tiTag.onmouseover = function (event) {
          prxO.oFly.flShow("%3Cdiv id=%22pr0xFlyCt-Div%22%3E" + prxO.oTim.tiFirst.over + "%3C/div%3E",event,0);
        };
        this.tiTag.onmouseout = prxO.oFly.flDHide;
        this.tiTag.onclick = prxO.oTim.tiClick;
        this.tiTag.oncontextmenu = prxO.oTim.tiFirst.rclick;

        prxO.oInt.inDOMready(this.tiTag, 1);
      }

      // Append the data of the current timer instance to a "command-line"
      // array.
      this.tiColl[this.tiColl.length] = [meth, func, time];
    },

    // The "onclick" function for the timer button.  Works like a toggle.
    tiClick : function () {
      var i, j, m, ceci = arguments.callee;
      if (!ceci.ids) ceci.ids = [];

      // Case 1:  We've pushed the button before, it displays "stop" now, so
      // that's what we do here.
      if (ceci.start == 1) {
        ceci.start = 0;
        prxO.oTim.tiTag.value = "timer";
        window.setTimeout = function () { return true; };
        window.setInterval = function () { return true; };

        // Stop all previously triggered timer IDs.
        while (ceci.ids.length) {
          i = ceci.ids.shift();
          window.clearTimeout(i);
          window.clearInterval(i);
        }

      // Case 0:  Button displays "timer".  We want to start all captured
      // timers with the current click.
      } else {
        ceci.start = 1;
        prxO.oTim.tiTag.value = " stop ";
        window.setTimeout = PrxRLsetTimeout;
        window.setInterval = PrxRLsetInterval;

        // Run the "command-line" array that contains all timer requests.
        // Trigger a timer with passed params, add the timer ID to another
        // array, so that it can be stopped later.
        for (j = 0; m = prxO.oTim.tiColl[j]; j++)
          ceci.ids[ceci.ids.length] = window["PrxRL" + m[0]](m[1], m[2]);
      }
    }

  };

  // Intercept "setTimeout".
  // Catch all calls which are still running after 10 seconds, or which are
  // scheduled after more than 1 second...
  // ...unless it's Mozilla's internal scrolldelay function for Marquees,
  // or we've clicked into the window within the 10 seconds.
  if (prxO.oSet.$stopMe & 4) window.setTimeout = function (func, time) {
    try { var pT = prxO.oTop.prxO.oAss.asLastClick; } catch (er) {}
    if (!pT && !prxO.oAss.asLastClick && !prxO.oSet.$_frameset) {
      if (!func) return PrxRLsetTimeout(func, time);

      var fn = String(func),
      si = /^[^(]*slide/i,
      se = /^(l7[1-9]\(|\n*function myTimeOutFunction|[^(]*menu)/i;
      var fx = fn.substr(0, fn.indexOf("(")); fx += " "; fx += time;

      if (!prxO.oTim.tiCount) prxO.oTim.tiCount = {};
      if (!prxO.oTim.tiCount[fx]) prxO.oTim.tiCount[fx] = 0;
      if ((
           time > 1000 ||
           time > 49 && time * prxO.oTim.tiCount[fx] > 10000 ||
           (!time || time < 50) && prxO.oTim.tiCount[fx] > 200 ||
           fn.search(si) != -1
         ) && fn.search(se) == -1)
        return prxO.oTim.tiAppend("setTimeout", func, time);

      prxO.oTim.tiCount[fx] = ++prxO.oTim.tiCount[fx];
      return PrxRLsetTimeout(func, time);
    }
    window.setTimeout = PrxRLsetTimeout;
    return setTimeout(func, time);
  };

  // Intercept "setInterval".
  if (prxO.oSet.$stopMe & 8) window.setInterval = function (func, time) {
    try { var pT = prxO.oTop.prxO.oAss.asLastClick; } catch (er) {}
    if (!pT && !prxO.oAss.asLastClick) {
      var fn = String(func);
      if (fn.indexOf(".apply") > 0 && time > 12 && time < 41)
        return PrxRLsetInterval(func, time);
      var s = /^(_cL\(|TM[a-z]\.TM0|um\.n\.)|clearInterval|\._tryPreloadAttach/;
      if (fn.search(s) > -1)
        return PrxRLsetInterval(func, time);

      // Expand and test the called function, if any.
      var r = /^(?:\n?function ?\(\w*\)[\s\n]?{[\s\n]*)?([\w$]+) ?\([^)]*\)\W*$/;
      if ((r = fn.match(r)) && (r = window[r[1]]) && String(r).search(s) > -1)
        return PrxRLsetInterval(func, time);

      return prxO.oTim.tiAppend("setInterval", func, time);
    }
    window.setInterval = PrxRLsetInterval;
    return setInterval(func, time);
  };

}

/* ====================================
   Scope for run-and-forget code.
   ==================================== */

(function () {

  // Inject our style sheets. - sidki, JD
  if (!prxO.oSet.$_cssSpec) prxO.oSet.$_cssSpec = [];
  if (prxO.oSet.$css & 2) prxO.oSet.$_cssSpec.push("links");
  if (prxO.oSet.$css & 4)
    prxO.oiIsIE  ? prxO.oSet.$_cssSpec.push("general", "g-ie") :
    prxO.oiIsMoz ? prxO.oSet.$_cssSpec.push("general", "g-moz") :
    prxO.oiIsOp  ? prxO.oSet.$_cssSpec.push("general", "g-op") :
    prxO.oiIsW3C ? prxO.oSet.$_cssSpec.push("general", "g-w3c") :
    prxO.oSet.$_cssSpec.push("general");
  if (prxO.oSet.$_cssSpec.length) prxO.oNce.ncCSSAdd();

  // Fix the Location object. - sidki
  // Strip Proxomitron URL commands from the "host", "hostname", and "href"
  // properties.  Set "protocol" to "https:", if the URL command was "https..".
  // Because "Location" cannot be manipulated in IE, we need to create new
  // properties and rename the native ones with a webfilter.
  var pxL = location, pxHn = pxL.hostname, pxR = pxL.PRXhref = pxL.href,
  pxRj = pxR.indexOf("?prx-"), pxHi, pxRi;

  pxHi = ((pxHi = pxHn.indexOf("..")) != -1) ?
    pxHi + 2 : ((pxHi = pxHn.indexOf("-px-.")) != -1) ? pxHi + 5 : null;
  pxRi = ((pxRi = pxR.indexOf("..")) != -1) ?
    pxRi + 2 : ((pxRi = pxR.indexOf("-px-.")) != -1) ? pxRi + 5 : null;

  pxL.PRXprotocol = (pxHn.search(/https(\.|-px-)\./) != -1) ? "https:" : pxL.protocol;
  pxL.PRXhostname = pxHi ? pxHn.substr(pxHi) : pxHn;
  pxL.PRXhost = pxHi ? pxL.host.substr(pxHi) : pxL.host;
  if (pxHi && pxRi) pxL.PRXhref = pxL.PRXprotocol + "//" + pxR.substr(pxRi);
  if (pxRj != -1) pxL.PRXhref = pxL.PRXhref.substr(0, pxRj);

  // "hash", and hence "href", are dynamic properties in Mozilla.
  if (pxL.__defineGetter__ && pxL.PRXhref == pxR) {
    pxL.PRXhref = null;
    pxL.__defineGetter__("PRXhref", function() { return location.href; });
    pxL.__defineSetter__("PRXhref", function() {});
  }

  // Fix the Navigator object. - sidki
  // The "JSProperties" blocklist is renaming several Navigator properties.
  // These get defined below.
  var pxN, pxU = navigator.PRXuserAgent;
  if (pxU) {
    if ((pxN = pxU.match(/\d[^)]+\)/))) {
      navigator.PRXappVersion = navigator.PRXappMinorVersion = pxN[0];
      navigator.PRXappName =
        (pxU.indexOf("Mozilla/4.0") == 0) ? "Microsoft Internet Explorer" :
        (pxU.indexOf("Mozilla/") == 0) ? "Netscape" :
        (pxU.indexOf("Opera/") == 0) ? "Opera" : "";
      if (pxU.indexOf("Gecko/") > 0) navigator.PRXproduct = "Gecko";
    }
    navigator.PRXcpuClass = "alpha";
    if (navigator.userLanguage) navigator.PRXuserLanguage = "en";
    if (navigator.browserLanguage) navigator.PRXbrowserLanguage = "en";
    if (navigator.systemLanguage) navigator.PRXsystemLanguage = "en";
    navigator.PRXjavaEnabled = navigator.PRXcookieEnabled = true;
  } else {
    pxN = ["userAgent", "appVersion", "appMinorVersion", "appName", "product",
      "cpuClass", "userLanguage", "browserLanguage", "systemLanguage",
      "cookieEnabled"];
    while (pxN.length) navigator["PRX" + pxN[0]] = navigator[pxN.shift()];
  }

  // Permanent handles for W3C & IE event registration methods Part I.
  var i, pxZ, pxA = [];
  if (window.addEventListener) pxA[pxA.length] = "addEventListener";
  if (window.attachEvent) pxA[pxA.length] = "attachEvent";
  for (i = 0; pxA[i]; i++) {
    pxZ = pxA[i];
    window["PrxRL" + pxZ] = window[pxZ];
    document["PrxRL" + pxZ] = document[pxZ];

    // Various Event Listeners to Buttons Part I (start of page). - sidki
    if (prxO.oSet.$toButton & 2)
      window[pxZ] = document[pxZ] = function (evn, fn, cap) {
        return (
          prxO.oInt.inButListen(this, evn, fn, cap) ||
          this["PrxRL" + pxZ](evn, fn, cap)
        );
      };
  }

  // Remove this script from the DOM.
  prxO.oInt.inDone("pr0xScrLink");

}) ();

/* ====================================
   Prepare node that gets populated later on.
   ==================================== */

prxO.oAss.asDivNode = prxO.oInt.inMakeEl("div");

/* ====================================
   Get Window Names Part II. - z12, sidki
   ==================================== */

// Detect the top window of this document, and if former isn't the current
// window, create a container to store the names of all frames.
if (!(prxO.oSet.$toDo & 128)) {
  prxO.oAss.asUpCount = 0;
  try {
    while (
      prxO.oTop != prxO.oTop.parent

      // If "parent" is a window name, the routine would break:
      && prxO.oTop.parent.name != "parent"

      // Opera 9: throw a cross-site security error too:
      && prxO.oTop.parent.document.domain
           ) {
      prxO.oTop = prxO.oTop.parent;
      prxO.oAss.asUpCount++;
    }
  } catch (er) {}
}

// Opera fires the top window's onload event before the child frames have
// loaded.  Also, an early "window.open" may try to load a page into to an
// existing child frame.  Adding the children's names with the onload function
// would be too late, so we do it now, and once more later.
if (prxO.oTop.prxO && prxO.oTop.prxO.oInt) prxO.oNce.ncTgAdd(window);

/* ====================================
   Register our onload event Part I (first addition). - z12
   Doing it here - the top of page - makes it the last onload event in IE.
   Frameset documents need this as well, because the Proxomitron end-of-page
   script isn't parsed there.  If we are not using IE, and this is not a
   frameset, "ncLoad" will be swapped to the end of the onload chain later.
   ==================================== */

prxO.oInt.inEventAdd(window, "load", prxO.oNce.ncLoad);

/* ====================================
   Anti-Popup Code. - Scott R. Lemmon
   ==================================== */

if (prxO.oSet.$popUp & (1 | 32)) {
  prxO.oAss.asLastClick = 0;
  prxO.oiIsMoz ? Window.prototype.PrxRLopen = Window.prototype.open :
    PrxRLopen = window.open;

  window.open = function (url, enam, atr, hist) {
    var ceci = arguments.callee;

    // When blocking a popup, return an object with dummy "open" methods.
    function dummyWin(why) {
      // Grab the PopUp URL for notification function.
      if (prxO.oSet.$popUp & (2 | 4)) {
        prxO.oInt.inPopURL(url, enam, why);
        ceci.countB = ++ceci.countB || 1;
        if (ceci.countB == 10) prxO.oSet.$popUp = 1;
      }

      return {
        focus : function () {}, blur : function () {}, close : function () {},
        moveTo : function () {}, resizeTo : function () {}
      };
    }

    // Site-specific switch -- Silently block all popups.
    if (prxO.oSet.$popUp & 32) return dummyWin();

    // Block popups triggered by onclick handlers for document, window,
    // and document.body (doesn't work in IE).
    var eArg, cArg;
    if ((eArg = window.event)) cArg = eArg.currentTarget || eArg.srcElement;
    else {
      var cCaller, bCaller = arguments.callee;
      while ((bCaller = bCaller.caller) && bCaller != cCaller)
        cCaller = bCaller;
      if (cCaller)
        // "deprecated" strict warning in Fx for cCaller.arguments .
        for (var i = 0, dArg = cCaller.arguments; i < dArg.length; i++)
          if ((eArg = dArg[i]) && (cArg = eArg.currentTarget)) break;
    }
    if (cArg && eArg.type.search(/click|mousedown|mouseup/) == 0 &&
      (cArg == document || cArg == window || cArg == document.body))
      return dummyWin(eArg.type + " " + String(cArg));

    // Make sure that popup windows have desired browser controls.
    function atrSet() {
      var odim, ndim,
      xatr = "location=1,status=1,scrollbars=1,resizable=1" +
        ((prxO.oSet.$popUp & 16) ? ",toolbar=1,menubar=1" : "");
      if (typeof atr != "string") atr = "";
      if (atr) odim = atr.match(/left[=:](\d+)/i);
      ndim = screen.width * .01;
      xatr += ",left="; xatr += (odim && odim[1] < ndim) ? odim[1] : ndim;
      if (atr) odim = atr.match(/top[=:](\d+)/i);
      ndim = screen.height * (prxO.oiIsOp ? .05 : .12);
      xatr += ",top="; xatr += (odim && odim[1] < ndim) ? odim[1] : ndim;
      if (atr) odim = atr.match(/height[=:](\d+)/i);
      xatr += ",height="; xatr += odim ? odim[1] : 480;
      if (atr) odim = atr.match(/width[=:](\d+)/i);
      xatr += ",width="; xatr += odim ? odim[1] : 640;
      return xatr;
    }

    // To reroute showModalDialog/showModelessDialog, the second parameter MUST
    // be tested/converted to string if need be since dialogs can also accept
    // objects, whereas "open" only accepts strings as second parameter.
    // A further problem can arise in the third parameter.  The dialog calls
    // have a slightly different format.  Size for instance is passed
    // differently and uses a semicolon instead of an equal sign. - TEggHead
    ceci.countA = ++ceci.countA || 1;
    var nam = (typeof enam != "string") ? enam ? "Dialog" : "prx_pop_" + ceci.countA : enam;

    // IE doesn't support "apply" for window.open, so pass on the correct
    // number of arguments the hard way. - sidki
    var le = arguments.length;
    function argGet() {
      switch (le) {
        case 0  : return PrxRLopen();
        case 1  : return PrxRLopen(url);
        case 2  : return PrxRLopen(url, nam);
        case 4  : return PrxRLopen(url, nam, atr, hist);
        default : return PrxRLopen(url, nam, atr);
      }
    }

    // Allow windows referring to trusted target names - Paul Rupe
    if (enam == nam && prxO.oInt.inTgCheck(nam)) return argGet();

    // If this page has already loaded and the mouse was clicked within
    // 2 seconds, allow the new window.
    var op, ti = new prxO.oAss.asDate().getTime(),
    sc = ti - prxO.oAss.asLastClick < 2000,
    tc = (prxO.oTop == window) ?
      false : ti - prxO.oTop.prxO.oAss.asLastClick < 2000;

    // If the current window already is an onsite popup, fine too. - sidki
    try { op = window.opener.location.href != window.location.href }
    catch (er) {}

    if (op || prxO.oiLoaded == 3 && (sc || tc))
      return atr ? (prxO.oSet.$popUp & (8 | 16)) ?
        PrxRLopen(url, nam, atrSet()) : argGet() : PrxRLopen(url, nam);

    return dummyWin();
  }

  // IE Specific Methods. - Homeric
  if (prxO.oiIsIE)
    window.showModalDialog = window.showModelessDialog = window.open;
}

/* ====================================
   Prevent Window Resizing Part I. - sidki
   Intercept "window.resizeTo" and "window.moveTo" for all windows except
   popups.  Note that Mozilla/Nescape windows can also be resized with
   "innerWidth=this; outerHeight=that".  This gets blocked the hard way in the
   "JSProperties" list, and - in case of a popup - restored by Part II.
   ==================================== */

if (prxO.oSet.$toDo & 64 && prxO.oAss.asWinNormal) {
  if (prxO.oiIsMoz) {
    Window.prototype.PrxRLmoveTo = Window.prototype.moveTo;
    Window.prototype.PrxRLresizeTo = Window.prototype.resizeTo;
  } else {
    PrxRLmoveTo = window.moveTo;
    PrxRLresizeTo = window.resizeTo;
  }

  window.moveTo = function (pxX, pxY) {
    prxO.oInt.inFooter(3, "moveTo blocked", pxX + "x" + pxY);
    return true;
  };

  window.resizeTo = function (pxX, pxY) {
    prxO.oInt.inFooter(3, "resizeTo blocked",
      pxX ? pxX + " x " + pxY : "proprietary method");
    return true;
  };

  if (prxO.oiIsMoz) window.sizeToContent = window.resizeTo;
}

/* ====================================
   Block randomizers.  Return a constant for calls to the Math.random() method.
   - sidki, z12
   ==================================== */

if (prxO.oSet._catchRnd) {
  Math.PrxRLrandom = Math.random;
  Math.random = function () {
    if (--prxO.oSet._catchRnd > 0) return 0.99999999999999;
    Math.random = Math.PrxRLrandom;
    return Math.random();
  }
}

/* ====================================
   Block various Methods. - Paul Rupe, sidki
   ==================================== */

if (prxO.oSet.$stopMe & 1) {

  // Override some window manipulation APIs (which never should have existed in
  // the first place).
  window.focus =
  window.blur =
  window.resizeBy =
  window.moveBy = PrxVoidF;

  if (prxO.oiIsIE) {
    prxVoidV = function createPopup() {};
    prxVoidV = function clipboardData() {};
    prxVoidV = "";
  }

  // Override these window properties as well.
  function status() { return true; }
  status.prox = true;
}

/* ====================================
   Show error messages in the footer.  IE and Mozilla only for now. - sidki
   ==================================== */

if (prxO.oSet._catchErrors && !prxO.oiIsOp) {
  prxO.oNce.ncOnerror = function (pxMsg, file, line) {
    if (prxO.oSet._catchErrors-- > 0) prxO.oInt.inFooter(4, "JS Error", pxMsg);
    return false;
  }
  window.onerror = prxO.oNce.ncOnerror;
}

/* ====================================
   Restrict Message Boxes. - Paul Rupe, sidki
   ==================================== */

if (prxO.oSet._catchBoxes) {
  if (prxO.oiIsMoz) {
    Window.prototype.PrxRLalert = Window.prototype.alert;
    Window.prototype.PrxRLprompt = Window.prototype.prompt;
    Window.prototype.PrxRLconfirm = Window.prototype.confirm;
  } else {
    PrxRLalert = window.alert;
    PrxRLprompt = window.prompt;
    PrxRLconfirm = window.confirm;
  }

  // Returns false if alert/confirm/prompt have been called a bunch of times
  // already.  Used to stop runaway scripts abusing these popup functions.
  prxO.oInt.inBoxCheck = function () {
    var ceci = arguments.callee;
    if (ceci.count == undefined) ceci.count = prxO.oSet._catchBoxes;
    --ceci.count;
    if (!prxO.oAss.asLastClick || ceci.count < -1) {
      if (ceci.count < -1) throw "Prox: JS killed again!";
      return false;
    }
    if (ceci.count >= 0) return true;
    var msg = "\t*** PROXOMITRON ALERT ***\nThis page has already launched " +
      prxO.oSet._catchBoxes + " dialog boxes.\n" +
      "Block further ones?\t\t-> Press OK\n" +
      "Or allow another " + prxO.oSet._catchBoxes + "?\t-> Press Cancel";
    if (PrxRLconfirm(msg)) {
      ceci.count = -2;
      throw "Prox: JS killed!";
    }
    ceci.count = prxO.oSet._catchBoxes;
    return true;
  }

  window.confirm = function (msg) {
    return prxO.oInt.inBoxCheck() ? PrxRLconfirm(msg) :
      prxO.oInt.inBoxCheck.count >= 7 ?
      prxO.oInt.inFooter(3, "JS Confirm", msg) : null;
  };

  window.prompt = function (msg, d) {
    return prxO.oInt.inBoxCheck() ? PrxRLprompt(msg, d || "") :
      prxO.oInt.inBoxCheck.count >= 7 ?
      prxO.oInt.inFooter(3, "JS Prompt", msg) : null;
  };

  window.alert = function (msg) {
    return (prxO.oInt.inBoxCheck() && !(prxO.oSet.$toDo & 8)) ? PrxRLalert(msg) :
      (prxO.oiLoaded > 2 || prxO.oInt.inBoxCheck.count >= 7) ?
      prxO.oInt.inFooter(3, "JS Alert", msg) : null;
  };
}

/* ====================================
   Intercept calls to "location.replace" Part I. - Paul Rupe, sidki
   IE/Opera only -- Mozilla: "replace" is read-only -- Konqueror: Redirect loop
   ==================================== */

if ((prxO.oiIsIE || prxO.oiIsOp) && prxO.oSet.$toDo & 16 &&
     !prxO.oSet.$_frameset && window.parent == window) {
  PrxRLreplace = location.replace;

  window.location.replace = function (l) {
    if (prxO.oiLoaded < 3) { prxO.inCatchLocURL = l; return false; }
    window.location.replace = PrxRLreplace;
    return location.replace(l);
  };
}

/* ====================================
   Proxomitron Menu Part I. - sidki
   ==================================== */

if (prxO.oSet.$toDo & 1) {
  prxO.oMen = {

    // Prepare icon insertion.
    mePics : [new Image(), new Image()],
    meWriteI : function () {
      this.meImg = prxO.oInt.inMakeEl("div");
      this.meImg.id = "pr0xMi-Div";
      this.meImg.onmouseover = function () { this.style.backgroundImage = "url(" + prxO.oMen.mePics[1].src + ")"; prxO.oMen.meShow(); };
      this.meImg.onmouseout = function () { this.style.backgroundImage = "url(" + prxO.oMen.mePics[0].src + ")"; prxO.oMen.meHide(); };
      this.meImg.onclick = function () { this.style.display = "none"; };
      if (prxO.oiIsMoz || prxO.oiIsOp) {
        var bImg = prxO.oInt.inMakeEl("img");
        bImg.src = "data:image/gif;base64,R0lGODlhAQABAJAAAAAAAAAAACH5BAUQAAAALAAAAAABAAEAAAICBAEAOw==";
        bImg.alt = "prox";
        this.meImg.appendChild(bImg);
      }
      prxO.oNce.ncDocFrag.appendChild(this.meImg);
    },

    // Initialize the menu upon first mouse click.
    meInit : function (e) {
      var tn = prxO.oMen.meCheck(e);
      if (!tn) return;
      prxO.oMen.meTimer = 0;

      // Set some of an object's event handlers to null Part III. - Paul Rupe
      if (prxO.oSet.$stopMe & 2) prxO.oInt.inClearEvent(document);

      // Load the menu style sheet.
      var cTag, cSS, pxA = ((prxO.oSet.$css & 8) ? "" : "http:/");
      pxA += "/local.ptron/sidki_h_"; pxA += prxO.oSet.$_cfg;
      pxA += "/CSS/dummy.css?join=menu";
      if (prxO.oiIsMoz) pxA += ",m-moz";
      else if (prxO.oiIsIE) pxA += (prxO.oiIsIE > 1) ? ",m-ie" : ",m-ie7";
      else if (prxO.oiIsOp) pxA += (prxO.oiIsOp >= 10) ? ",m-op" : ",m-op9";
      else if (prxO.oiIsW3C) pxA += ",m-w3c";
      if (typeof document.createStyleSheet == "object") {
        cSS = true;
        cTag = document.createStyleSheet();
        cTag.addImport(pxA);
        cTag = cTag.owningElement;
      }
      else cTag = prxO.oInt.inMakeEl("style");
      cTag.lang = "x-prox-css";
      cTag.media = "all";
      cTag.type = "text/css";
      if (!cSS) {
        cTag.textContent = "@import url(" + pxA + ");";
        document.getElementsByTagName("head")[0].appendChild(cTag);
      }

      // Prepare the menu insertion.
      prxO.oMen.meDiv = prxO.oInt.inMakeEl("div");
      prxO.oMen.meDiv.id = "pr0xM-Div";
      prxO.oInt.inSetCSS(prxO.oMen.meDiv, "position: absolute !important; " +
        "left: 0; top: 0; visibility: hidden;");
      var tg = "/local.ptron/sidki_h_" + prxO.oSet.$_cfg + "/proxjs-x-menu.js";
      function doAppend(s) {
        if (s) eval(XHR.responseText);
        else {
          var tagS = prxO.oInt.inMakeEl("script");
          tagS.src = "http:/" + tg;
          tagS.type = "text/javascript";
          tagS.id = "pr0xScrMenu";
          prxO.oBody.appendChild(tagS);
        }
      }

      // Get menu data.  Use XMLHttpRequest if supported, else fall back to
      // slower standard request.
      var XHR = window.XMLHttpRequest ? new XMLHttpRequest() : null;
      if (!XHR && window.ActiveXObject)
        for (var i = 0, msXHR = [6, 4, 3], m; m = msXHR[i]; i++)
          try { XHR = new ActiveXObject("MSXML2.XMLHttp." + m + ".0"); break; }
          catch (er) {}
      if (!XHR || prxO.oMen.meSet[7] || !location.host) doAppend(0);
      else {
        XHR.open("GET", location.protocol + "//" + location.host + tg);
        XHR.onreadystatechange = function () {
          if (XHR.readyState != 4) return;
          try { if (XHR.status != 200) return; }
          catch (er) { throw "Prox exit: " + location.href; }
          doAppend(1); XHR = null;
        };
        XHR.send(null);
      }

      function miHide() {
        if (prxO.oMen.meImg.style.visibility == "visible")
          PrxRLsetTimeout(function () { prxO.oMen.meImg.style.visibility = "hidden"; }, 150);
      }

      function miShow(e) {
        if (e !== 1 && !prxO.oMen.meCheck(e)) return;
        if (prxO.oMen.meImg.style.visibility == "visible") return;
        prxO.oInt.inSetCSS(prxO.oMen.meImg, "left: " +
          ((window.pageXOffset || prxO.oDoc.scrollLeft) +
          prxO.oDoc.clientWidth - prxO.oAss.asWidth - 50) +
          "px; top: " + ((window.pageYOffset || prxO.oDoc.scrollTop) +
          prxO.oDoc.clientHeight - 50) + "px; visibility: visible;");
      }

      prxO.oInt.inEventRem(prxO.oiIsMoz ? window : document, "click", prxO.oMen.meInit, true);
      if (prxO.oiIsIE) { // IE can't intercept during capture phase.
        if (tn == "html") prxO.oInt.inEventAdd(document, "click", miShow, true);
        prxO.oInt.inEventRem(prxO.oBody, "click", prxO.oMen.meInit);
        prxO.oInt.inEventAdd(prxO.oBody, "click", miShow);
      } else {
        prxO.oInt.inEventAdd(prxO.oiIsMoz ? window : document, "click", miShow, true);
        prxO.oInt.inEventAdd(window, "resize", miHide);
      }
      if (prxO.oiIsMoz) prxO.oInt.inEventAdd(window, "DOMMouseScroll", miHide);
      prxO.oInt.inEventAdd(window, "scroll", miHide);
      miShow(1);

      if (prxO.oSet.$_level < 5) {
        delete prxO.oInt.inClearEvent;
        delete prxO.oMen.meWriteI;
        delete prxO.oMen.meInit;
      }

    },

    // Check if this mouse click should get intercepted.
    meCheck : function (e) {
      e = e || window.event;
      if (e.button) return false;
      var tag = e.target || e.srcElement, tn = tag.tagName.toLowerCase();
      if (tn.search(/^(?:a(?:rea)?|button|embed|input|object)$/) == 0) return false;
      for (var i = 0, t; i < 2 && (t = (tag = tag.parentNode).tagName); i++)
        if (t.toLowerCase() == "a") return false;
      return tn;
    },

    // Show the menu.
    meShow : function () {
      clearTimeout(this.meTimer);
      if (this.meDiv.style.visibility == "visible") return;
      var self = this;

      function showMe() {
        self.meDone = ++self.meDone || 0;
        var pW = prxO.oMen.meDiv.offsetWidth;
        if (self.meDone < 50 && !pW)
          return self.meTimer = PrxRLsetTimeout(arguments.callee, 500);

        prxO.oInt.inSetCSS(prxO.oMen.meDiv, "left: " +
          ((window.pageXOffset || prxO.oDoc.scrollLeft) +
          prxO.oDoc.clientWidth - prxO.oAss.asWidth - pW - 50) +
          "px; top: " + ((window.pageYOffset || prxO.oDoc.scrollTop) +
          prxO.oDoc.clientHeight - prxO.oMen.meDiv.offsetHeight - 50) +
          "px; visibility: visible;");
        self.meDone = null;
        return true;
      }

      this.meTimer = PrxRLsetTimeout(showMe, 150);
    },

    // Hide the menu.
    meHide : function () {
      clearTimeout(this.meTimer);
      if (this.meDiv.style.visibility == "hidden") return;
      this.meTimer = PrxRLsetTimeout(function () {
        prxO.oMen.meDiv.style.visibility = "hidden";
      }, 150);
    }

  };

  prxO.oMen.mePics[0].src = "http://local.ptron/sidki_h_" + prxO.oSet.$_cfg + "/proxm-cold.gif";
  prxO.oMen.mePics[1].src = "http://local.ptron/sidki_h_" + prxO.oSet.$_cfg + "/proxm-hot.gif";
}
