/*****************************************************************************
 *
 * proxjs-min.js -- external script for sidki's Proxomitron config
 *
 * This is the stripped-down version, used in "minimal config mode", and with
 * Netscape 4.x.
 *
 * Last edited: 2009-07-18
 *
 *****************************************************************************/

/* ====================================
   Namespace for various assignments.
   ==================================== */

prxO.oAss = {

  // May get overwritten.
  asDate : Date,

  // Does this browser support cssText and/or XPath?
  asTcss : document.documentElement && document.documentElement.style &&
    document.documentElement.style.cssText != undefined,
  asXpath : !!document.evaluate

};

/* ====================================
   Set some flags -- The "prxO" object has been created already.
   ==================================== */

// This flag indicates where we currently are in our script. Three stages:
// 1 -> Beginning.
// 2 -> End of page.
// 3 -> Onload event has completed.
prxO.oiLoaded = 1;

// Browser detection. - hpguru
if (window.opera)
  prxO.oiIsOp = window.opera.version ? window.opera.version() : 1;
else if (document.getElementById) {
  if (document.all) prxO.oiIsIE = document.documentMode || 1;
  else if (window.Window) prxO.oiIsMoz = true;
  else prxO.oiIsW3C = true;
}
else if (document.layers) prxO.oiIsNN = true;

/* ====================================
   Required References and Declarations.
   ==================================== */

// May get overwritten.
document.PrxRLcreateElement = document.createElement;

// Replaced browser info.
document.PRXreferrer = unescape(prxO.oNce.ncFrom);
navigator.PRXuserAgent = prxO.oNce.ncWith;

// Dummies.
var prxVoidV = "";
function PrxVoidF() { return ""; }

// Prophylactic definitions.
var expires = new Date(0);

// Called by Proxomitron instead of the real names.
if (prxO.oiIsMoz) {
  Window.prototype.PrxRLsetTimeout = Window.prototype.setTimeout;
  Window.prototype.PrxRLsetInterval = Window.prototype.setInterval;
} else {
  PrxRLsetTimeout = window.setTimeout;
  PrxRLsetInterval = window.setInterval;
}

/* ====================================
   Namespace for internal routines. - ...
   ==================================== */

prxO.oInt = {

  // Choose the right method for creating and getting tags, depending on
  // whether an XML namespace is present or not.
  inMakeEl : function (el) {
    return prxO.oSet.$_xns ? document.createElementNS(prxO.oSet.$_xns, el) :
      document.PrxRLcreateElement(el);
  },
  inGetEl : function (el) {
    if (!document.getElementsByTagName) return false;
    return prxO.oSet.$_xns ? document.getElementsByTagNameNS(prxO.oSet.$_xns, el) :
      document.getElementsByTagName(el);
  },

  // Choose the right method for setting the style attribute value.
  inSetCSS : function (node, css) {
    if (prxO.oAss.asTcss) node.style.cssText = css;
    else node.setAttribute("style", css);
  },

  // Temporary handles for the W3C and IE event unregistration methods.
  inEventRemT : prxO.oiIsIE ? window.detachEvent : window.removeEventListener,

  // Cross-browser event listener registration and unregistration
  // - Mozilla/IE/Opera/NN4. - Scott Andrew LePera
  // Modified for minimal script.
  inEventAdd : function (obj, evn, fn, cap) {
    var rl = (obj == window || obj == document) ? "PrxRL" : "";
    if (!prxO.oiIsIE && obj.addEventListener)
      obj[rl + "addEventListener"](evn, fn, cap || false);
    else if (obj.attachEvent)
      obj[rl + "attachEvent"]("on" + evn, fn);
    else obj["on" + evn] = fn;
  },
  inEventRem : function (obj, evn, fn, cap) {
    if (!prxO.oiIsIE && obj.removeEventListener) {
      if (this.inEventRemT) {
        window.removeEventListener = this.inEventRemT;
        delete this.inEventRemT;
      }
      obj.removeEventListener(evn, fn, cap || false);
    } else if (obj.detachEvent) {
      if (this.inEventRemT) {
        window.detachEvent = this.inEventRemT;
        delete this.inEventRemT;
      }
      obj.detachEvent("on" + evn, fn);
    }
  },

  // Set some of an object's event handlers to null Part I. - Paul Rupe
  // Modified for minimal script.
  inClearEvent : function (pxA) {
    if (!pxA) return;
    var pxE = [
      "onmouseleave",
      "onmouseout",
      "onmousewheel",
      "onblur",
      "onfocus",
      "onfocusout",
      "oncontextmenu",
      "oncopy",
      "ondeactivate",
      "onhelp",
      "onlosecapture",
      "onpropertychange",
      "onscroll",
      "onselect",
      "onselectstart",
      "onbeforeunload",
      "onunload"
    ];

    // Asking the Document object for defined event handlers is slow,
    // so nullify them unconditionally there.
    for (var i = 0, pxO; pxO = pxE[i]; i++)
      if (pxA == document || pxA[pxO]) pxA[pxO] = null;
  },

  // Get the 'n'th ancestor of given node. - Sadiq
  inGoUp : function (node, n) {
    for (var i = 0; i < n; i++) node = node.parentNode; return node;
  },

  // Toggle (show/hide) specified tags. - sidki
  inToggleA : function () {
    for (var i = 0, pxA, pxH; pxA = arguments[i]; i++) {
      if (pxA.style.display == "none" || pxA.style.visibility == "hidden") {
        if (prxO.oiIsIE || pxA.tagName.toLowerCase() == "span") {
          pxA.style.display = "inline"; pxA.style.visibility = "visible";
        } else {
          pxH = prxO.oAss.asTcss ? pxA.style.cssText : pxA.getAttribute("style");
          pxH = pxH.replace(/((display|visibility): *(none|hidden)[; ]*)+/i, "");
          pxH ? prxO.oInt.inSetCSS(pxA, pxH) : pxA.removeAttribute("style");
        }
      } else { pxA.style.display = "none"; pxA.style.visibility = "hidden"; }
    }
  },
  inToggleB : function (nam, atr, tags, num) {
    var m, i, a, t, tagThis, tagArray = tags.split(",");
    num = num || 0;
    for (m = 0; a = tagArray[m]; m++) {
      tagThis = this.inGetEl(a);
      for (i = 0; t = tagThis[i]; i++)
        if ((atr == "cl" && nam == t.className.split(" ")[num]) ||
          (atr == "id" && nam == t.id)) {
          if (nam == "Pr0xFlash") this.inToggleD(t);
          else this.inToggleA(t);
        }
    }
  },

  // Weapon of mass destruction...
  inDone : function (x) {
    if (prxO.oSet.$_level >= 5) return;
    if (x) x = document.getElementById ? document.getElementById(x) : null;
    else {
      x = this.inGetEl("script");
      if (x) x = x[x.length - 1];
    }
    if (x) x.parentNode.removeChild(x);
  }

};

/* ====================================
   Namespace for initial temporary functions.
   ==================================== */

prxO.oNce = {

  // Insert our CSS.
  ncCSSAdd : function () {
    var pxA = ((prxO.oSet.$css & 8) ? "" : "http:/");
    pxA += "/local.ptron/sidki_h_"; pxA += prxO.oSet.$_cfg;
    pxA += "/CSS/dummy.css?join="; pxA += prxO.oSet.$_cssSpec.join();
    if (!document.PrxRLcreateElement) {
      document.write("\n<link rel=\"stylesheet\" type=\"text/css\" href=\"" +
        pxA + "\"" + prxO.oSet.$_xml + ">");
      return;
    }
    var pxG = this.ncStyle;
    this.ncStyle = prxO.oInt.inMakeEl("style"),
    this.ncStyle.lang = "x-prox-css";
    this.ncStyle.media = "all";
    this.ncStyle.type = "text/css";
    if (!prxO.oiIsIE) this.ncStyle.textContent = "@import url(" + pxA + ");";
    var pxS = document.getElementById("pr0xScrLink");
    if (pxG && pxG.parentNode) pxG.parentNode.replaceChild(this.ncStyle, pxG);
    else if (!pxS) {
      if ((pxS = document.styleSheets) && (pxS = pxS[0]) &&
           (pxS = pxS.owningElement || pxS.ownerNode))
        pxS.parentNode.insertBefore(this.ncStyle, pxS);
      else if ((pxS = prxO.oInt.inGetEl("head")[0]))
        pxS.appendChild(this.ncStyle);
      else return;
    }
    else if (pxS.nextSibling) pxS.parentNode.insertBefore(this.ncStyle, pxS.nextSibling);
    else pxS.parentNode.appendChild(this.ncStyle);
    if (prxO.oiIsIE) this.ncStyle.styleSheet.addImport(pxA);
  },

  // Executed at end of page.
  // Modified for minimal script.
  ncBottom : function () {

    // Register our onload event Part II (removal). - sidki
    // The previous registration was needed for framesets, which won't see this
    // part of code.  And for IE, which is excluded.
    if (!prxO.oiIsIE) prxO.oInt.inEventRem(window, "load", this.ncLoad);

    // Register our onload event Part III (re-add -> move to end-of-chain).
    // Executed outside framesets and for standards-compliant browsers only.
    if (!prxO.oiIsIE) prxO.oInt.inEventAdd(window, "load", this.ncLoad);

    // We've reached the end of the page.
    prxO.oiLoaded = 2;
  },

  // Run this function at the very last. - ...
  // Modified for minimal script.
  ncFinal : function () {

    // Set some of an object's event handlers to null Part II. - Paul Rupe
    // Modified for minimal script.
    if (prxO.oSet.$stopMe & 2) {
      prxO.oInt.inClearEvent(document);
      prxO.oInt.inClearEvent(document.body);
      prxO.oInt.inClearEvent(window);
    }

    // Track last click if interception of popups, timers, or message boxes is
    // turned on. - Scott R. Lemmon
    // Modified for minimal script.
    if (prxO.oSet.$popUp & 1 || prxO.oSet._catchBoxes)
      if (prxO.oiIsNN) document.captureEvents(Event.MOUSEUP);
      prxO.oInt.inEventAdd(document, "mouseup", function () {
        prxO.oAss.asLastClick = window.parent.prxO.oAss.asLastClick =
          new prxO.oAss.asDate().getTime();
      }, true);

  },

  // The function that gets registered with the onload event.  Keep it simple
  // to avoid memory leaks in Mozilla.
  // Modified for minimal script.
  ncLoad : function () {

    // If our environment is gone, return (XMLHttpRequest/Ajax).
    if (!window.prxO) return;

    // Final jobs.
    prxO.oNce.ncFinal();

    // All done.
    prxO.oiLoaded = 3;
  }

};

/* ====================================
   Clickable flyover Part I. - Dynamic Drive, sidki, Martin Konicek
   ==================================== */

// Modified for minimal script.
prxO.oFly = {
  flShow : function () {},
  flDHide : function () {},
  flLink : function () {}
};

/* ====================================
   Scope for run-and-forget code.
   ==================================== */

(function () {

  // Inject our style sheets. - sidki, JD
  if (!prxO.oSet.$_cssSpec) prxO.oSet.$_cssSpec = [];
  if (prxO.oSet.$css & 2) prxO.oSet.$_cssSpec.push("links");
  if (prxO.oSet.$css & 4)
    prxO.oiIsIE  ? prxO.oSet.$_cssSpec.push("general", "g-ie") :
    prxO.oiIsMoz ? prxO.oSet.$_cssSpec.push("general", "g-moz") :
    prxO.oiIsOp  ? prxO.oSet.$_cssSpec.push("general", "g-op") :
    prxO.oiIsW3C ? prxO.oSet.$_cssSpec.push("general", "g-w3c") :
    prxO.oSet.$_cssSpec.push("general");
  if (prxO.oSet.$_cssSpec.length) prxO.oNce.ncCSSAdd();

  // Fix the Location object. - sidki
  // Strip Proxomitron URL commands from the "host", "hostname", and "href"
  // properties.  Set "protocol" to "https:", if the URL command was "https..".
  // Because "Location" cannot be manipulated in IE, we need to create new
  // properties and rename the native ones with a webfilter.
  var pxL = location, pxHn = pxL.hostname, pxR = pxL.PRXhref = pxL.href,
  pxRj = pxR.indexOf("?prx-"), pxHi, pxRi;

  pxHi = ((pxHi = pxHn.indexOf("..")) != -1) ?
    pxHi + 2 : ((pxHi = pxHn.indexOf("-px-.")) != -1) ? pxHi + 5 : null;
  pxRi = ((pxRi = pxR.indexOf("..")) != -1) ?
    pxRi + 2 : ((pxRi = pxR.indexOf("-px-.")) != -1) ? pxRi + 5 : null;

  pxL.PRXprotocol = (pxHn.search(/https(\.|-px-)\./) != -1) ? "https:" : pxL.protocol;
  pxL.PRXhostname = pxHi ? pxHn.substr(pxHi) : pxHn;
  pxL.PRXhost = pxHi ? pxL.host.substr(pxHi) : pxL.host;
  if (pxHi && pxRi) pxL.PRXhref = pxL.PRXprotocol + "//" + pxR.substr(pxRi);
  if (pxRj != -1) pxL.PRXhref = pxL.PRXhref.substr(0, pxRj);

  // "hash", and hence "href", are dynamic properties in Mozilla.
  if (pxL.__defineGetter__ && pxL.PRXhref == pxR) {
    pxL.PRXhref = null;
    pxL.__defineGetter__("PRXhref", function() { return location.href; });
    pxL.__defineSetter__("PRXhref", function() {});
  }

  // Fix the Navigator object. - sidki
  // The "JSProperties" blocklist is renaming several Navigator properties.
  // These get defined below.
  var pxN, pxU = navigator.PRXuserAgent;
  if (pxU) {
    if ((pxN = pxU.match(/\d[^)]+\)/))) {
      navigator.PRXappVersion = navigator.PRXappMinorVersion = pxN[0];
      navigator.PRXappName =
        (pxU.indexOf("Mozilla/4.0") == 0) ? "Microsoft Internet Explorer" :
        (pxU.indexOf("Mozilla/") == 0) ? "Netscape" :
        (pxU.indexOf("Opera/") == 0) ? "Opera" : "";
      if (pxU.indexOf("Gecko/") > 0) navigator.PRXproduct = "Gecko";
    }
    navigator.PRXcpuClass = "alpha";
    if (navigator.userLanguage) navigator.PRXuserLanguage = "en";
    if (navigator.browserLanguage) navigator.PRXbrowserLanguage = "en";
    if (navigator.systemLanguage) navigator.PRXsystemLanguage = "en";
    navigator.PRXjavaEnabled = navigator.PRXcookieEnabled = true;
  } else {
    pxN = ["userAgent", "appVersion", "appMinorVersion", "appName", "product",
      "cpuClass", "userLanguage", "browserLanguage", "systemLanguage",
      "cookieEnabled"];
    while (pxN.length) navigator["PRX" + pxN[0]] = navigator[pxN.shift()];
  }

  // Permanent handles for W3C & IE event registration methods Part I.
  // Modified for minimal script.
  var i, pxZ, pxA = [];
  if (window.addEventListener) pxA[pxA.length] = "addEventListener";
  if (window.attachEvent) pxA[pxA.length] = "attachEvent";
  for (i = 0; pxA[i]; i++) {
    pxZ = pxA[i];
    window["PrxRL" + pxZ] = window[pxZ];
    document["PrxRL" + pxZ] = document[pxZ];
  }

  // Remove this script from the DOM.
  prxO.oInt.inDone("pr0xScrLink");

}) ();

/* ====================================
   Register our onload event Part I (first addition). - z12
   Doing it here - the top of page - makes it the last onload event in IE.
   Frameset documents need this as well, because the Proxomitron end-of-page
   script isn't parsed there.  If we are not using IE, and this is not a
   frameset, "ncLoad" will be swapped to the end of the onload chain later.
   ==================================== */

prxO.oInt.inEventAdd(window, "load", prxO.oNce.ncLoad);

/* ====================================
   Anti-Popup Code. - Scott R. Lemmon
   ==================================== */

if (prxO.oSet.$popUp & (1 | 32)) {
  prxO.oAss.asLastClick = 0;
  prxO.oiIsMoz ? Window.prototype.PrxRLopen = Window.prototype.open :
    PrxRLopen = window.open;

  window.open = function (url, enam, atr, hist) {
    var ceci = arguments.callee;

    // When blocking a popup, return an object with dummy "open" methods.
    // Modified for minimal script.
    function dummyWin() {
      return {
        focus : function () {}, blur : function () {}, close : function () {},
        moveTo : function () {}, resizeTo : function () {}
      };
    }

    // Make sure that popup windows have desired browser controls.
    function atrSet() {
      var odim, ndim,
      xatr = "location=1,status=1,scrollbars=1,resizable=1" +
        ((prxO.oSet.$popUp & 16) ? ",toolbar=1,menubar=1" : "");
      if (typeof atr != "string") atr = "";
      if (atr) odim = atr.match(/left[=:](\d+)/i);
      ndim = screen.width * .01;
      xatr += ",left="; xatr += (odim && odim[1] < ndim) ? odim[1] : ndim;
      if (atr) odim = atr.match(/top[=:](\d+)/i);
      ndim = screen.height * (prxO.oiIsOp ? .05 : .12);
      xatr += ",top="; xatr += (odim && odim[1] < ndim) ? odim[1] : ndim;
      if (atr) odim = atr.match(/height[=:](\d+)/i);
      xatr += ",height="; xatr += odim ? odim[1] : 480;
      if (atr) odim = atr.match(/width[=:](\d+)/i);
      xatr += ",width="; xatr += odim ? odim[1] : 640;
      return xatr;
    }

    // To reroute showModalDialog/showModelessDialog, the second parameter MUST
    // be tested/converted to string if need be since dialogs can also accept
    // objects, whereas "open" only accepts strings as second parameter.
    // A further problem can arise in the third parameter.  The dialog calls
    // have a slightly different format.  Size for instance is passed
    // differently and uses a semicolon instead of an equal sign. - TEggHead
    ceci.countA = ++ceci.countA || 1;
    var nam = (typeof enam != "string") ? enam ? "Dialog" : "prx_pop_" + ceci.countA : enam;

    // IE doesn't support "apply" for window.open, so pass on the correct
    // number of arguments the hard way. - sidki
    var le = arguments.length;
    function argGet() {
      switch (le) {
        case 0  : return PrxRLopen();
        case 1  : return PrxRLopen(url);
        case 2  : return PrxRLopen(url, nam);
        case 4  : return PrxRLopen(url, nam, atr, hist);
        default : return PrxRLopen(url, nam, atr);
      }
    }

    // Allow windows referring to trusted target names - Paul Rupe
    // Modified for minimal script.
    if (enam == nam && nam.indexOf("prx_") == 0) return argGet();

    // If this page has already loaded and the mouse was clicked within
    // 2 seconds, allow the new window.
    // Modified for minimal script.
    var ti = new prxO.oAss.asDate().getTime(),
    sc = ti - prxO.oAss.asLastClick < 2000,
    tc = (window.parent == window) ?
      false : ti - window.parent.prxO.oAss.asLastClick < 2000;

    // Modified for minimal script.
    if (prxO.oiLoaded == 3 && (sc || tc))
      return atr ? (prxO.oSet.$popUp & (8 | 16)) ?
        PrxRLopen(url, nam, atrSet()) : argGet() : PrxRLopen(url, nam);

    return dummyWin();
  }

  // IE Specific Methods. - Homeric
  if (prxO.oiIsIE)
    window.showModalDialog = window.showModelessDialog = window.open;
}

/* ====================================
   Block various Methods. - Paul Rupe, sidki
   ==================================== */

if (prxO.oSet.$stopMe & 1) {

  // Override some window manipulation APIs (which never should have existed in
  // the first place).
  window.focus =
  window.blur =
  window.resizeBy =
  window.moveBy = PrxVoidF;

  if (prxO.oiIsIE) {
    prxVoidV = function createPopup() {};
    prxVoidV = function clipboardData() {};
    prxVoidV = "";
  }

  // Override these window properties as well.
  function status() { return true; }
}

/* ====================================
   Restrict Message Boxes. - Paul Rupe, sidki
   ==================================== */

if (prxO.oSet._catchBoxes) {
  if (prxO.oiIsMoz) {
    Window.prototype.PrxRLalert = Window.prototype.alert;
    Window.prototype.PrxRLprompt = Window.prototype.prompt;
    Window.prototype.PrxRLconfirm = Window.prototype.confirm;
  } else {
    PrxRLalert = window.alert;
    PrxRLprompt = window.prompt;
    PrxRLconfirm = window.confirm;
  }

  // Returns false if alert/confirm/prompt have been called a bunch of times
  // already.  Used to stop runaway scripts abusing these popup functions.
  // Modified for minimal script.
  prxO.oInt.inBoxCheck = function () {
    var ceci = arguments.callee;
    if (ceci.count == undefined) ceci.count = prxO.oSet._catchBoxes;
    --ceci.count;
    if (!prxO.oAss.asLastClick || ceci.count < -1) {
      return false;
    }
    if (ceci.count >= 0) return true;
    var msg = "\t*** PROXOMITRON ALERT ***\nThis page has already launched " +
      prxO.oSet._catchBoxes + " dialog boxes.\n" +
      "Block further ones?\t\t-> Press OK\n" +
      "Or allow another " + prxO.oSet._catchBoxes + "?\t-> Press Cancel";
    if (PrxRLconfirm(msg)) {
      ceci.count = -2;
      return false;
    }
    ceci.count = prxO.oSet._catchBoxes;
    return true;
  }

  // Modified for minimal script.
  window.confirm = function (msg) {
    return prxO.oInt.inBoxCheck() ? PrxRLconfirm(msg) : null;
  };

  // Modified for minimal script.
  window.prompt = function (msg, d) {
    return prxO.oInt.inBoxCheck() ? PrxRLprompt(msg, d || "") : null;
  };

  // Modified for minimal script.
  window.alert = function (msg) {
    return prxO.oInt.inBoxCheck() ? PrxRLalert(msg) : null;
  };
}
